# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class SysCodeConfigInputOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'point_type_code': 'str',
        'point_type': 'str',
        'code': 'str',
        'online_point_code': 'str',
        'point_name': 'str',
        'is_input_point': 'bool',
        'ext_info': 'str',
        'i_ext_info': 'int',
        'reserve': 'str',
        'product_line': 'str',
        'model_name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'point_type_code': 'pointTypeCode',
        'point_type': 'pointType',
        'code': 'code',
        'online_point_code': 'onlinePointCode',
        'point_name': 'pointName',
        'is_input_point': 'isInputPoint',
        'ext_info': 'extInfo',
        'i_ext_info': 'iExtInfo',
        'reserve': 'reserve',
        'product_line': 'productLine',
        'model_name': 'modelName'
    }

    def __init__(self, id=None, point_type_code=None, point_type=None, code=None, online_point_code=None, point_name=None, is_input_point=None, ext_info=None, i_ext_info=None, reserve=None, product_line=None, model_name=None, local_vars_configuration=None):  # noqa: E501
        """SysCodeConfigInputOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._point_type_code = None
        self._point_type = None
        self._code = None
        self._online_point_code = None
        self._point_name = None
        self._is_input_point = None
        self._ext_info = None
        self._i_ext_info = None
        self._reserve = None
        self._product_line = None
        self._model_name = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.point_type_code = point_type_code
        self.point_type = point_type
        self.code = code
        self.online_point_code = online_point_code
        self.point_name = point_name
        if is_input_point is not None:
            self.is_input_point = is_input_point
        self.ext_info = ext_info
        if i_ext_info is not None:
            self.i_ext_info = i_ext_info
        self.reserve = reserve
        self.product_line = product_line
        self.model_name = model_name

    @property
    def id(self):
        """Gets the id of this SysCodeConfigInputOutput.  # noqa: E501


        :return: The id of this SysCodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SysCodeConfigInputOutput.


        :param id: The id of this SysCodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def point_type_code(self):
        """Gets the point_type_code of this SysCodeConfigInputOutput.  # noqa: E501


        :return: The point_type_code of this SysCodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._point_type_code

    @point_type_code.setter
    def point_type_code(self, point_type_code):
        """Sets the point_type_code of this SysCodeConfigInputOutput.


        :param point_type_code: The point_type_code of this SysCodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._point_type_code = point_type_code

    @property
    def point_type(self):
        """Gets the point_type of this SysCodeConfigInputOutput.  # noqa: E501


        :return: The point_type of this SysCodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._point_type

    @point_type.setter
    def point_type(self, point_type):
        """Sets the point_type of this SysCodeConfigInputOutput.


        :param point_type: The point_type of this SysCodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._point_type = point_type

    @property
    def code(self):
        """Gets the code of this SysCodeConfigInputOutput.  # noqa: E501


        :return: The code of this SysCodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this SysCodeConfigInputOutput.


        :param code: The code of this SysCodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def online_point_code(self):
        """Gets the online_point_code of this SysCodeConfigInputOutput.  # noqa: E501

        在线点位PointCode  # noqa: E501

        :return: The online_point_code of this SysCodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._online_point_code

    @online_point_code.setter
    def online_point_code(self, online_point_code):
        """Sets the online_point_code of this SysCodeConfigInputOutput.

        在线点位PointCode  # noqa: E501

        :param online_point_code: The online_point_code of this SysCodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._online_point_code = online_point_code

    @property
    def point_name(self):
        """Gets the point_name of this SysCodeConfigInputOutput.  # noqa: E501


        :return: The point_name of this SysCodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._point_name

    @point_name.setter
    def point_name(self, point_name):
        """Sets the point_name of this SysCodeConfigInputOutput.


        :param point_name: The point_name of this SysCodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._point_name = point_name

    @property
    def is_input_point(self):
        """Gets the is_input_point of this SysCodeConfigInputOutput.  # noqa: E501


        :return: The is_input_point of this SysCodeConfigInputOutput.  # noqa: E501
        :rtype: bool
        """
        return self._is_input_point

    @is_input_point.setter
    def is_input_point(self, is_input_point):
        """Sets the is_input_point of this SysCodeConfigInputOutput.


        :param is_input_point: The is_input_point of this SysCodeConfigInputOutput.  # noqa: E501
        :type: bool
        """

        self._is_input_point = is_input_point

    @property
    def ext_info(self):
        """Gets the ext_info of this SysCodeConfigInputOutput.  # noqa: E501


        :return: The ext_info of this SysCodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._ext_info

    @ext_info.setter
    def ext_info(self, ext_info):
        """Sets the ext_info of this SysCodeConfigInputOutput.


        :param ext_info: The ext_info of this SysCodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._ext_info = ext_info

    @property
    def i_ext_info(self):
        """Gets the i_ext_info of this SysCodeConfigInputOutput.  # noqa: E501


        :return: The i_ext_info of this SysCodeConfigInputOutput.  # noqa: E501
        :rtype: int
        """
        return self._i_ext_info

    @i_ext_info.setter
    def i_ext_info(self, i_ext_info):
        """Sets the i_ext_info of this SysCodeConfigInputOutput.


        :param i_ext_info: The i_ext_info of this SysCodeConfigInputOutput.  # noqa: E501
        :type: int
        """

        self._i_ext_info = i_ext_info

    @property
    def reserve(self):
        """Gets the reserve of this SysCodeConfigInputOutput.  # noqa: E501


        :return: The reserve of this SysCodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._reserve

    @reserve.setter
    def reserve(self, reserve):
        """Sets the reserve of this SysCodeConfigInputOutput.


        :param reserve: The reserve of this SysCodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._reserve = reserve

    @property
    def product_line(self):
        """Gets the product_line of this SysCodeConfigInputOutput.  # noqa: E501


        :return: The product_line of this SysCodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._product_line

    @product_line.setter
    def product_line(self, product_line):
        """Sets the product_line of this SysCodeConfigInputOutput.


        :param product_line: The product_line of this SysCodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._product_line = product_line

    @property
    def model_name(self):
        """Gets the model_name of this SysCodeConfigInputOutput.  # noqa: E501


        :return: The model_name of this SysCodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this SysCodeConfigInputOutput.


        :param model_name: The model_name of this SysCodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SysCodeConfigInputOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SysCodeConfigInputOutput):
            return True

        return self.to_dict() != other.to_dict()
