# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class AddModelPrecisionConfigInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'region_name': 'str',
        'rec_probability': 'str',
        'region_s_value': 'float',
        'region_e_value': 'float',
        'sort': 'int',
        'code': 'str'
    }

    attribute_map = {
        'region_name': 'regionName',
        'rec_probability': 'recProbability',
        'region_s_value': 'regionSValue',
        'region_e_value': 'regionEValue',
        'sort': 'sort',
        'code': 'code'
    }

    def __init__(self, region_name=None, rec_probability=None, region_s_value=None, region_e_value=None, sort=None, code=None, local_vars_configuration=None):  # noqa: E501
        """AddModelPrecisionConfigInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._region_name = None
        self._rec_probability = None
        self._region_s_value = None
        self._region_e_value = None
        self._sort = None
        self._code = None
        self.discriminator = None

        self.region_name = region_name
        self.rec_probability = rec_probability
        if region_s_value is not None:
            self.region_s_value = region_s_value
        if region_e_value is not None:
            self.region_e_value = region_e_value
        if sort is not None:
            self.sort = sort
        self.code = code

    @property
    def region_name(self):
        """Gets the region_name of this AddModelPrecisionConfigInput.  # noqa: E501

        百分比区间名称,如:80-100(优秀) precision region name  # noqa: E501

        :return: The region_name of this AddModelPrecisionConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._region_name

    @region_name.setter
    def region_name(self, region_name):
        """Sets the region_name of this AddModelPrecisionConfigInput.

        百分比区间名称,如:80-100(优秀) precision region name  # noqa: E501

        :param region_name: The region_name of this AddModelPrecisionConfigInput.  # noqa: E501
        :type: str
        """

        self._region_name = region_name

    @property
    def rec_probability(self):
        """Gets the rec_probability of this AddModelPrecisionConfigInput.  # noqa: E501

        百分比区间推荐:如:>70 precison region recommended proportion  # noqa: E501

        :return: The rec_probability of this AddModelPrecisionConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._rec_probability

    @rec_probability.setter
    def rec_probability(self, rec_probability):
        """Sets the rec_probability of this AddModelPrecisionConfigInput.

        百分比区间推荐:如:>70 precison region recommended proportion  # noqa: E501

        :param rec_probability: The rec_probability of this AddModelPrecisionConfigInput.  # noqa: E501
        :type: str
        """

        self._rec_probability = rec_probability

    @property
    def region_s_value(self):
        """Gets the region_s_value of this AddModelPrecisionConfigInput.  # noqa: E501

        百分比区间开始,如:80 precision region start value  # noqa: E501

        :return: The region_s_value of this AddModelPrecisionConfigInput.  # noqa: E501
        :rtype: float
        """
        return self._region_s_value

    @region_s_value.setter
    def region_s_value(self, region_s_value):
        """Sets the region_s_value of this AddModelPrecisionConfigInput.

        百分比区间开始,如:80 precision region start value  # noqa: E501

        :param region_s_value: The region_s_value of this AddModelPrecisionConfigInput.  # noqa: E501
        :type: float
        """

        self._region_s_value = region_s_value

    @property
    def region_e_value(self):
        """Gets the region_e_value of this AddModelPrecisionConfigInput.  # noqa: E501

        百分比区间截止,如:100 precision region end value  # noqa: E501

        :return: The region_e_value of this AddModelPrecisionConfigInput.  # noqa: E501
        :rtype: float
        """
        return self._region_e_value

    @region_e_value.setter
    def region_e_value(self, region_e_value):
        """Sets the region_e_value of this AddModelPrecisionConfigInput.

        百分比区间截止,如:100 precision region end value  # noqa: E501

        :param region_e_value: The region_e_value of this AddModelPrecisionConfigInput.  # noqa: E501
        :type: float
        """

        self._region_e_value = region_e_value

    @property
    def sort(self):
        """Gets the sort of this AddModelPrecisionConfigInput.  # noqa: E501

        排序号,越小越靠前 precision region index  # noqa: E501

        :return: The sort of this AddModelPrecisionConfigInput.  # noqa: E501
        :rtype: int
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this AddModelPrecisionConfigInput.

        排序号,越小越靠前 precision region index  # noqa: E501

        :param sort: The sort of this AddModelPrecisionConfigInput.  # noqa: E501
        :type: int
        """

        self._sort = sort

    @property
    def code(self):
        """Gets the code of this AddModelPrecisionConfigInput.  # noqa: E501

        指标 system point code  # noqa: E501

        :return: The code of this AddModelPrecisionConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this AddModelPrecisionConfigInput.

        指标 system point code  # noqa: E501

        :param code: The code of this AddModelPrecisionConfigInput.  # noqa: E501
        :type: str
        """

        self._code = code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddModelPrecisionConfigInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddModelPrecisionConfigInput):
            return True

        return self.to_dict() != other.to_dict()
