# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class ConfigurationModel(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'flow_ratio_offset': 'float',
        'weir_height_offset': 'float',
        'flow_ratio_of_factory4': 'float',
        'flow_ratio_of_factory4_lower': 'float',
        'flow_ratio_of_factory4_upper': 'float',
        'q2max': 'float',
        'sum_set2_1': 'float',
        'sum_set2_2': 'float',
        'sum_set2_3': 'float',
        'sum_set2_4': 'float',
        'k_q2_1': 'float',
        'k_q2_2': 'float',
        'k_q2_3': 'float',
        'k_q2_4': 'float',
        'k_q2_5': 'float',
        'd_q2': 'float',
        'q3max': 'float',
        'sum_set3_1': 'float',
        'sum_set3_2': 'float',
        'sum_set3_3': 'float',
        'sum_set3_4': 'float',
        'k_q3_1': 'float',
        'k_q3_2': 'float',
        'k_q3_3': 'float',
        'k_q3_4': 'float',
        'k_q3_5': 'float',
        'd_q3': 'float',
        'q4max': 'float',
        'sum_set4_1': 'float',
        'sum_set4_2': 'float',
        'sum_set4_3': 'float',
        'sum_set4_4': 'float',
        'k_q4_1': 'float',
        'k_q4_2': 'float',
        'k_q4_3': 'float',
        'k_q4_4': 'float',
        'k_q4_5': 'float',
        'd_q4': 'float'
    }

    attribute_map = {
        'flow_ratio_offset': 'flowRatioOffset',
        'weir_height_offset': 'weirHeightOffset',
        'flow_ratio_of_factory4': 'flowRatioOfFactory4',
        'flow_ratio_of_factory4_lower': 'flowRatioOfFactory4Lower',
        'flow_ratio_of_factory4_upper': 'flowRatioOfFactory4Upper',
        'q2max': 'q2max',
        'sum_set2_1': 'sumSet2_1',
        'sum_set2_2': 'sumSet2_2',
        'sum_set2_3': 'sumSet2_3',
        'sum_set2_4': 'sumSet2_4',
        'k_q2_1': 'kQ2_1',
        'k_q2_2': 'kQ2_2',
        'k_q2_3': 'kQ2_3',
        'k_q2_4': 'kQ2_4',
        'k_q2_5': 'kQ2_5',
        'd_q2': 'dQ2',
        'q3max': 'q3max',
        'sum_set3_1': 'sumSet3_1',
        'sum_set3_2': 'sumSet3_2',
        'sum_set3_3': 'sumSet3_3',
        'sum_set3_4': 'sumSet3_4',
        'k_q3_1': 'kQ3_1',
        'k_q3_2': 'kQ3_2',
        'k_q3_3': 'kQ3_3',
        'k_q3_4': 'kQ3_4',
        'k_q3_5': 'kQ3_5',
        'd_q3': 'dQ3',
        'q4max': 'q4max',
        'sum_set4_1': 'sumSet4_1',
        'sum_set4_2': 'sumSet4_2',
        'sum_set4_3': 'sumSet4_3',
        'sum_set4_4': 'sumSet4_4',
        'k_q4_1': 'kQ4_1',
        'k_q4_2': 'kQ4_2',
        'k_q4_3': 'kQ4_3',
        'k_q4_4': 'kQ4_4',
        'k_q4_5': 'kQ4_5',
        'd_q4': 'dQ4'
    }

    def __init__(self, flow_ratio_offset=None, weir_height_offset=None, flow_ratio_of_factory4=None, flow_ratio_of_factory4_lower=None, flow_ratio_of_factory4_upper=None, q2max=None, sum_set2_1=None, sum_set2_2=None, sum_set2_3=None, sum_set2_4=None, k_q2_1=None, k_q2_2=None, k_q2_3=None, k_q2_4=None, k_q2_5=None, d_q2=None, q3max=None, sum_set3_1=None, sum_set3_2=None, sum_set3_3=None, sum_set3_4=None, k_q3_1=None, k_q3_2=None, k_q3_3=None, k_q3_4=None, k_q3_5=None, d_q3=None, q4max=None, sum_set4_1=None, sum_set4_2=None, sum_set4_3=None, sum_set4_4=None, k_q4_1=None, k_q4_2=None, k_q4_3=None, k_q4_4=None, k_q4_5=None, d_q4=None, local_vars_configuration=None):  # noqa: E501
        """ConfigurationModel - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._flow_ratio_offset = None
        self._weir_height_offset = None
        self._flow_ratio_of_factory4 = None
        self._flow_ratio_of_factory4_lower = None
        self._flow_ratio_of_factory4_upper = None
        self._q2max = None
        self._sum_set2_1 = None
        self._sum_set2_2 = None
        self._sum_set2_3 = None
        self._sum_set2_4 = None
        self._k_q2_1 = None
        self._k_q2_2 = None
        self._k_q2_3 = None
        self._k_q2_4 = None
        self._k_q2_5 = None
        self._d_q2 = None
        self._q3max = None
        self._sum_set3_1 = None
        self._sum_set3_2 = None
        self._sum_set3_3 = None
        self._sum_set3_4 = None
        self._k_q3_1 = None
        self._k_q3_2 = None
        self._k_q3_3 = None
        self._k_q3_4 = None
        self._k_q3_5 = None
        self._d_q3 = None
        self._q4max = None
        self._sum_set4_1 = None
        self._sum_set4_2 = None
        self._sum_set4_3 = None
        self._sum_set4_4 = None
        self._k_q4_1 = None
        self._k_q4_2 = None
        self._k_q4_3 = None
        self._k_q4_4 = None
        self._k_q4_5 = None
        self._d_q4 = None
        self.discriminator = None

        if flow_ratio_offset is not None:
            self.flow_ratio_offset = flow_ratio_offset
        if weir_height_offset is not None:
            self.weir_height_offset = weir_height_offset
        if flow_ratio_of_factory4 is not None:
            self.flow_ratio_of_factory4 = flow_ratio_of_factory4
        if flow_ratio_of_factory4_lower is not None:
            self.flow_ratio_of_factory4_lower = flow_ratio_of_factory4_lower
        if flow_ratio_of_factory4_upper is not None:
            self.flow_ratio_of_factory4_upper = flow_ratio_of_factory4_upper
        if q2max is not None:
            self.q2max = q2max
        if sum_set2_1 is not None:
            self.sum_set2_1 = sum_set2_1
        if sum_set2_2 is not None:
            self.sum_set2_2 = sum_set2_2
        if sum_set2_3 is not None:
            self.sum_set2_3 = sum_set2_3
        if sum_set2_4 is not None:
            self.sum_set2_4 = sum_set2_4
        if k_q2_1 is not None:
            self.k_q2_1 = k_q2_1
        if k_q2_2 is not None:
            self.k_q2_2 = k_q2_2
        if k_q2_3 is not None:
            self.k_q2_3 = k_q2_3
        if k_q2_4 is not None:
            self.k_q2_4 = k_q2_4
        if k_q2_5 is not None:
            self.k_q2_5 = k_q2_5
        if d_q2 is not None:
            self.d_q2 = d_q2
        if q3max is not None:
            self.q3max = q3max
        if sum_set3_1 is not None:
            self.sum_set3_1 = sum_set3_1
        if sum_set3_2 is not None:
            self.sum_set3_2 = sum_set3_2
        if sum_set3_3 is not None:
            self.sum_set3_3 = sum_set3_3
        if sum_set3_4 is not None:
            self.sum_set3_4 = sum_set3_4
        if k_q3_1 is not None:
            self.k_q3_1 = k_q3_1
        if k_q3_2 is not None:
            self.k_q3_2 = k_q3_2
        if k_q3_3 is not None:
            self.k_q3_3 = k_q3_3
        if k_q3_4 is not None:
            self.k_q3_4 = k_q3_4
        if k_q3_5 is not None:
            self.k_q3_5 = k_q3_5
        if d_q3 is not None:
            self.d_q3 = d_q3
        if q4max is not None:
            self.q4max = q4max
        if sum_set4_1 is not None:
            self.sum_set4_1 = sum_set4_1
        if sum_set4_2 is not None:
            self.sum_set4_2 = sum_set4_2
        if sum_set4_3 is not None:
            self.sum_set4_3 = sum_set4_3
        if sum_set4_4 is not None:
            self.sum_set4_4 = sum_set4_4
        if k_q4_1 is not None:
            self.k_q4_1 = k_q4_1
        if k_q4_2 is not None:
            self.k_q4_2 = k_q4_2
        if k_q4_3 is not None:
            self.k_q4_3 = k_q4_3
        if k_q4_4 is not None:
            self.k_q4_4 = k_q4_4
        if k_q4_5 is not None:
            self.k_q4_5 = k_q4_5
        if d_q4 is not None:
            self.d_q4 = d_q4

    @property
    def flow_ratio_offset(self):
        """Gets the flow_ratio_offset of this ConfigurationModel.  # noqa: E501


        :return: The flow_ratio_offset of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._flow_ratio_offset

    @flow_ratio_offset.setter
    def flow_ratio_offset(self, flow_ratio_offset):
        """Sets the flow_ratio_offset of this ConfigurationModel.


        :param flow_ratio_offset: The flow_ratio_offset of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._flow_ratio_offset = flow_ratio_offset

    @property
    def weir_height_offset(self):
        """Gets the weir_height_offset of this ConfigurationModel.  # noqa: E501


        :return: The weir_height_offset of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._weir_height_offset

    @weir_height_offset.setter
    def weir_height_offset(self, weir_height_offset):
        """Sets the weir_height_offset of this ConfigurationModel.


        :param weir_height_offset: The weir_height_offset of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._weir_height_offset = weir_height_offset

    @property
    def flow_ratio_of_factory4(self):
        """Gets the flow_ratio_of_factory4 of this ConfigurationModel.  # noqa: E501


        :return: The flow_ratio_of_factory4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._flow_ratio_of_factory4

    @flow_ratio_of_factory4.setter
    def flow_ratio_of_factory4(self, flow_ratio_of_factory4):
        """Sets the flow_ratio_of_factory4 of this ConfigurationModel.


        :param flow_ratio_of_factory4: The flow_ratio_of_factory4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._flow_ratio_of_factory4 = flow_ratio_of_factory4

    @property
    def flow_ratio_of_factory4_lower(self):
        """Gets the flow_ratio_of_factory4_lower of this ConfigurationModel.  # noqa: E501


        :return: The flow_ratio_of_factory4_lower of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._flow_ratio_of_factory4_lower

    @flow_ratio_of_factory4_lower.setter
    def flow_ratio_of_factory4_lower(self, flow_ratio_of_factory4_lower):
        """Sets the flow_ratio_of_factory4_lower of this ConfigurationModel.


        :param flow_ratio_of_factory4_lower: The flow_ratio_of_factory4_lower of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._flow_ratio_of_factory4_lower = flow_ratio_of_factory4_lower

    @property
    def flow_ratio_of_factory4_upper(self):
        """Gets the flow_ratio_of_factory4_upper of this ConfigurationModel.  # noqa: E501


        :return: The flow_ratio_of_factory4_upper of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._flow_ratio_of_factory4_upper

    @flow_ratio_of_factory4_upper.setter
    def flow_ratio_of_factory4_upper(self, flow_ratio_of_factory4_upper):
        """Sets the flow_ratio_of_factory4_upper of this ConfigurationModel.


        :param flow_ratio_of_factory4_upper: The flow_ratio_of_factory4_upper of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._flow_ratio_of_factory4_upper = flow_ratio_of_factory4_upper

    @property
    def q2max(self):
        """Gets the q2max of this ConfigurationModel.  # noqa: E501


        :return: The q2max of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._q2max

    @q2max.setter
    def q2max(self, q2max):
        """Sets the q2max of this ConfigurationModel.


        :param q2max: The q2max of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._q2max = q2max

    @property
    def sum_set2_1(self):
        """Gets the sum_set2_1 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set2_1 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set2_1

    @sum_set2_1.setter
    def sum_set2_1(self, sum_set2_1):
        """Sets the sum_set2_1 of this ConfigurationModel.


        :param sum_set2_1: The sum_set2_1 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set2_1 = sum_set2_1

    @property
    def sum_set2_2(self):
        """Gets the sum_set2_2 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set2_2 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set2_2

    @sum_set2_2.setter
    def sum_set2_2(self, sum_set2_2):
        """Sets the sum_set2_2 of this ConfigurationModel.


        :param sum_set2_2: The sum_set2_2 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set2_2 = sum_set2_2

    @property
    def sum_set2_3(self):
        """Gets the sum_set2_3 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set2_3 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set2_3

    @sum_set2_3.setter
    def sum_set2_3(self, sum_set2_3):
        """Sets the sum_set2_3 of this ConfigurationModel.


        :param sum_set2_3: The sum_set2_3 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set2_3 = sum_set2_3

    @property
    def sum_set2_4(self):
        """Gets the sum_set2_4 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set2_4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set2_4

    @sum_set2_4.setter
    def sum_set2_4(self, sum_set2_4):
        """Sets the sum_set2_4 of this ConfigurationModel.


        :param sum_set2_4: The sum_set2_4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set2_4 = sum_set2_4

    @property
    def k_q2_1(self):
        """Gets the k_q2_1 of this ConfigurationModel.  # noqa: E501


        :return: The k_q2_1 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q2_1

    @k_q2_1.setter
    def k_q2_1(self, k_q2_1):
        """Sets the k_q2_1 of this ConfigurationModel.


        :param k_q2_1: The k_q2_1 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q2_1 = k_q2_1

    @property
    def k_q2_2(self):
        """Gets the k_q2_2 of this ConfigurationModel.  # noqa: E501


        :return: The k_q2_2 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q2_2

    @k_q2_2.setter
    def k_q2_2(self, k_q2_2):
        """Sets the k_q2_2 of this ConfigurationModel.


        :param k_q2_2: The k_q2_2 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q2_2 = k_q2_2

    @property
    def k_q2_3(self):
        """Gets the k_q2_3 of this ConfigurationModel.  # noqa: E501


        :return: The k_q2_3 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q2_3

    @k_q2_3.setter
    def k_q2_3(self, k_q2_3):
        """Sets the k_q2_3 of this ConfigurationModel.


        :param k_q2_3: The k_q2_3 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q2_3 = k_q2_3

    @property
    def k_q2_4(self):
        """Gets the k_q2_4 of this ConfigurationModel.  # noqa: E501


        :return: The k_q2_4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q2_4

    @k_q2_4.setter
    def k_q2_4(self, k_q2_4):
        """Sets the k_q2_4 of this ConfigurationModel.


        :param k_q2_4: The k_q2_4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q2_4 = k_q2_4

    @property
    def k_q2_5(self):
        """Gets the k_q2_5 of this ConfigurationModel.  # noqa: E501


        :return: The k_q2_5 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q2_5

    @k_q2_5.setter
    def k_q2_5(self, k_q2_5):
        """Sets the k_q2_5 of this ConfigurationModel.


        :param k_q2_5: The k_q2_5 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q2_5 = k_q2_5

    @property
    def d_q2(self):
        """Gets the d_q2 of this ConfigurationModel.  # noqa: E501


        :return: The d_q2 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._d_q2

    @d_q2.setter
    def d_q2(self, d_q2):
        """Sets the d_q2 of this ConfigurationModel.


        :param d_q2: The d_q2 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._d_q2 = d_q2

    @property
    def q3max(self):
        """Gets the q3max of this ConfigurationModel.  # noqa: E501


        :return: The q3max of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._q3max

    @q3max.setter
    def q3max(self, q3max):
        """Sets the q3max of this ConfigurationModel.


        :param q3max: The q3max of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._q3max = q3max

    @property
    def sum_set3_1(self):
        """Gets the sum_set3_1 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set3_1 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set3_1

    @sum_set3_1.setter
    def sum_set3_1(self, sum_set3_1):
        """Sets the sum_set3_1 of this ConfigurationModel.


        :param sum_set3_1: The sum_set3_1 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set3_1 = sum_set3_1

    @property
    def sum_set3_2(self):
        """Gets the sum_set3_2 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set3_2 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set3_2

    @sum_set3_2.setter
    def sum_set3_2(self, sum_set3_2):
        """Sets the sum_set3_2 of this ConfigurationModel.


        :param sum_set3_2: The sum_set3_2 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set3_2 = sum_set3_2

    @property
    def sum_set3_3(self):
        """Gets the sum_set3_3 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set3_3 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set3_3

    @sum_set3_3.setter
    def sum_set3_3(self, sum_set3_3):
        """Sets the sum_set3_3 of this ConfigurationModel.


        :param sum_set3_3: The sum_set3_3 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set3_3 = sum_set3_3

    @property
    def sum_set3_4(self):
        """Gets the sum_set3_4 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set3_4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set3_4

    @sum_set3_4.setter
    def sum_set3_4(self, sum_set3_4):
        """Sets the sum_set3_4 of this ConfigurationModel.


        :param sum_set3_4: The sum_set3_4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set3_4 = sum_set3_4

    @property
    def k_q3_1(self):
        """Gets the k_q3_1 of this ConfigurationModel.  # noqa: E501


        :return: The k_q3_1 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q3_1

    @k_q3_1.setter
    def k_q3_1(self, k_q3_1):
        """Sets the k_q3_1 of this ConfigurationModel.


        :param k_q3_1: The k_q3_1 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q3_1 = k_q3_1

    @property
    def k_q3_2(self):
        """Gets the k_q3_2 of this ConfigurationModel.  # noqa: E501


        :return: The k_q3_2 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q3_2

    @k_q3_2.setter
    def k_q3_2(self, k_q3_2):
        """Sets the k_q3_2 of this ConfigurationModel.


        :param k_q3_2: The k_q3_2 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q3_2 = k_q3_2

    @property
    def k_q3_3(self):
        """Gets the k_q3_3 of this ConfigurationModel.  # noqa: E501


        :return: The k_q3_3 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q3_3

    @k_q3_3.setter
    def k_q3_3(self, k_q3_3):
        """Sets the k_q3_3 of this ConfigurationModel.


        :param k_q3_3: The k_q3_3 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q3_3 = k_q3_3

    @property
    def k_q3_4(self):
        """Gets the k_q3_4 of this ConfigurationModel.  # noqa: E501


        :return: The k_q3_4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q3_4

    @k_q3_4.setter
    def k_q3_4(self, k_q3_4):
        """Sets the k_q3_4 of this ConfigurationModel.


        :param k_q3_4: The k_q3_4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q3_4 = k_q3_4

    @property
    def k_q3_5(self):
        """Gets the k_q3_5 of this ConfigurationModel.  # noqa: E501


        :return: The k_q3_5 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q3_5

    @k_q3_5.setter
    def k_q3_5(self, k_q3_5):
        """Sets the k_q3_5 of this ConfigurationModel.


        :param k_q3_5: The k_q3_5 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q3_5 = k_q3_5

    @property
    def d_q3(self):
        """Gets the d_q3 of this ConfigurationModel.  # noqa: E501


        :return: The d_q3 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._d_q3

    @d_q3.setter
    def d_q3(self, d_q3):
        """Sets the d_q3 of this ConfigurationModel.


        :param d_q3: The d_q3 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._d_q3 = d_q3

    @property
    def q4max(self):
        """Gets the q4max of this ConfigurationModel.  # noqa: E501


        :return: The q4max of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._q4max

    @q4max.setter
    def q4max(self, q4max):
        """Sets the q4max of this ConfigurationModel.


        :param q4max: The q4max of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._q4max = q4max

    @property
    def sum_set4_1(self):
        """Gets the sum_set4_1 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set4_1 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set4_1

    @sum_set4_1.setter
    def sum_set4_1(self, sum_set4_1):
        """Sets the sum_set4_1 of this ConfigurationModel.


        :param sum_set4_1: The sum_set4_1 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set4_1 = sum_set4_1

    @property
    def sum_set4_2(self):
        """Gets the sum_set4_2 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set4_2 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set4_2

    @sum_set4_2.setter
    def sum_set4_2(self, sum_set4_2):
        """Sets the sum_set4_2 of this ConfigurationModel.


        :param sum_set4_2: The sum_set4_2 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set4_2 = sum_set4_2

    @property
    def sum_set4_3(self):
        """Gets the sum_set4_3 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set4_3 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set4_3

    @sum_set4_3.setter
    def sum_set4_3(self, sum_set4_3):
        """Sets the sum_set4_3 of this ConfigurationModel.


        :param sum_set4_3: The sum_set4_3 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set4_3 = sum_set4_3

    @property
    def sum_set4_4(self):
        """Gets the sum_set4_4 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set4_4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set4_4

    @sum_set4_4.setter
    def sum_set4_4(self, sum_set4_4):
        """Sets the sum_set4_4 of this ConfigurationModel.


        :param sum_set4_4: The sum_set4_4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set4_4 = sum_set4_4

    @property
    def k_q4_1(self):
        """Gets the k_q4_1 of this ConfigurationModel.  # noqa: E501


        :return: The k_q4_1 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q4_1

    @k_q4_1.setter
    def k_q4_1(self, k_q4_1):
        """Sets the k_q4_1 of this ConfigurationModel.


        :param k_q4_1: The k_q4_1 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q4_1 = k_q4_1

    @property
    def k_q4_2(self):
        """Gets the k_q4_2 of this ConfigurationModel.  # noqa: E501


        :return: The k_q4_2 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q4_2

    @k_q4_2.setter
    def k_q4_2(self, k_q4_2):
        """Sets the k_q4_2 of this ConfigurationModel.


        :param k_q4_2: The k_q4_2 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q4_2 = k_q4_2

    @property
    def k_q4_3(self):
        """Gets the k_q4_3 of this ConfigurationModel.  # noqa: E501


        :return: The k_q4_3 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q4_3

    @k_q4_3.setter
    def k_q4_3(self, k_q4_3):
        """Sets the k_q4_3 of this ConfigurationModel.


        :param k_q4_3: The k_q4_3 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q4_3 = k_q4_3

    @property
    def k_q4_4(self):
        """Gets the k_q4_4 of this ConfigurationModel.  # noqa: E501


        :return: The k_q4_4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q4_4

    @k_q4_4.setter
    def k_q4_4(self, k_q4_4):
        """Sets the k_q4_4 of this ConfigurationModel.


        :param k_q4_4: The k_q4_4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q4_4 = k_q4_4

    @property
    def k_q4_5(self):
        """Gets the k_q4_5 of this ConfigurationModel.  # noqa: E501


        :return: The k_q4_5 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q4_5

    @k_q4_5.setter
    def k_q4_5(self, k_q4_5):
        """Sets the k_q4_5 of this ConfigurationModel.


        :param k_q4_5: The k_q4_5 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q4_5 = k_q4_5

    @property
    def d_q4(self):
        """Gets the d_q4 of this ConfigurationModel.  # noqa: E501


        :return: The d_q4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._d_q4

    @d_q4.setter
    def d_q4(self, d_q4):
        """Sets the d_q4 of this ConfigurationModel.


        :param d_q4: The d_q4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._d_q4 = d_q4

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConfigurationModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConfigurationModel):
            return True

        return self.to_dict() != other.to_dict()
