# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class DosingStatisticDailysInOut(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'statistic_code': 'str',
        'time': 'datetime',
        'value': 'float',
        'cost_value': 'float',
        'cal_value': 'float',
        'category': 'int',
        'product_line': 'str',
        'tenant_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'statistic_code': 'statisticCode',
        'time': 'time',
        'value': 'value',
        'cost_value': 'costValue',
        'cal_value': 'calValue',
        'category': 'category',
        'product_line': 'productLine',
        'tenant_id': 'tenantId'
    }

    def __init__(self, id=None, statistic_code=None, time=None, value=None, cost_value=None, cal_value=None, category=None, product_line=None, tenant_id=None, local_vars_configuration=None):  # noqa: E501
        """DosingStatisticDailysInOut - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._statistic_code = None
        self._time = None
        self._value = None
        self._cost_value = None
        self._cal_value = None
        self._category = None
        self._product_line = None
        self._tenant_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.statistic_code = statistic_code
        if time is not None:
            self.time = time
        if value is not None:
            self.value = value
        if cost_value is not None:
            self.cost_value = cost_value
        if cal_value is not None:
            self.cal_value = cal_value
        if category is not None:
            self.category = category
        self.product_line = product_line
        if tenant_id is not None:
            self.tenant_id = tenant_id

    @property
    def id(self):
        """Gets the id of this DosingStatisticDailysInOut.  # noqa: E501

        统计数据ID data id  # noqa: E501

        :return: The id of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DosingStatisticDailysInOut.

        统计数据ID data id  # noqa: E501

        :param id: The id of this DosingStatisticDailysInOut.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def statistic_code(self):
        """Gets the statistic_code of this DosingStatisticDailysInOut.  # noqa: E501

        统计编码 statistic code  # noqa: E501

        :return: The statistic_code of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: str
        """
        return self._statistic_code

    @statistic_code.setter
    def statistic_code(self, statistic_code):
        """Sets the statistic_code of this DosingStatisticDailysInOut.

        统计编码 statistic code  # noqa: E501

        :param statistic_code: The statistic_code of this DosingStatisticDailysInOut.  # noqa: E501
        :type: str
        """

        self._statistic_code = statistic_code

    @property
    def time(self):
        """Gets the time of this DosingStatisticDailysInOut.  # noqa: E501

        时间 time  # noqa: E501

        :return: The time of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this DosingStatisticDailysInOut.

        时间 time  # noqa: E501

        :param time: The time of this DosingStatisticDailysInOut.  # noqa: E501
        :type: datetime
        """

        self._time = time

    @property
    def value(self):
        """Gets the value of this DosingStatisticDailysInOut.  # noqa: E501

        实际投加值 actual dosage  # noqa: E501

        :return: The value of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this DosingStatisticDailysInOut.

        实际投加值 actual dosage  # noqa: E501

        :param value: The value of this DosingStatisticDailysInOut.  # noqa: E501
        :type: float
        """

        self._value = value

    @property
    def cost_value(self):
        """Gets the cost_value of this DosingStatisticDailysInOut.  # noqa: E501

        药耗值 actual dosage cost  # noqa: E501

        :return: The cost_value of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: float
        """
        return self._cost_value

    @cost_value.setter
    def cost_value(self, cost_value):
        """Sets the cost_value of this DosingStatisticDailysInOut.

        药耗值 actual dosage cost  # noqa: E501

        :param cost_value: The cost_value of this DosingStatisticDailysInOut.  # noqa: E501
        :type: float
        """

        self._cost_value = cost_value

    @property
    def cal_value(self):
        """Gets the cal_value of this DosingStatisticDailysInOut.  # noqa: E501

        计算投加值 calculated dosage  # noqa: E501

        :return: The cal_value of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: float
        """
        return self._cal_value

    @cal_value.setter
    def cal_value(self, cal_value):
        """Sets the cal_value of this DosingStatisticDailysInOut.

        计算投加值 calculated dosage  # noqa: E501

        :param cal_value: The cal_value of this DosingStatisticDailysInOut.  # noqa: E501
        :type: float
        """

        self._cal_value = cal_value

    @property
    def category(self):
        """Gets the category of this DosingStatisticDailysInOut.  # noqa: E501

        药剂投加类别  # noqa: E501

        :return: The category of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: int
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this DosingStatisticDailysInOut.

        药剂投加类别  # noqa: E501

        :param category: The category of this DosingStatisticDailysInOut.  # noqa: E501
        :type: int
        """
        allowed_values = [1, 2, 3, 4]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and category not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `category` ({0}), must be one of {1}"  # noqa: E501
                .format(category, allowed_values)
            )

        self._category = category

    @property
    def product_line(self):
        """Gets the product_line of this DosingStatisticDailysInOut.  # noqa: E501

        生产线代码 product line code  # noqa: E501

        :return: The product_line of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: str
        """
        return self._product_line

    @product_line.setter
    def product_line(self, product_line):
        """Sets the product_line of this DosingStatisticDailysInOut.

        生产线代码 product line code  # noqa: E501

        :param product_line: The product_line of this DosingStatisticDailysInOut.  # noqa: E501
        :type: str
        """

        self._product_line = product_line

    @property
    def tenant_id(self):
        """Gets the tenant_id of this DosingStatisticDailysInOut.  # noqa: E501

        租户ID tenant id  # noqa: E501

        :return: The tenant_id of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this DosingStatisticDailysInOut.

        租户ID tenant id  # noqa: E501

        :param tenant_id: The tenant_id of this DosingStatisticDailysInOut.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DosingStatisticDailysInOut):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DosingStatisticDailysInOut):
            return True

        return self.to_dict() != other.to_dict()
