# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class RoleDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'remarks': 'str',
        'is_default': 'bool',
        'extra_properties': 'str',
        'creation_time': 'datetime',
        'creator_id': 'str',
        'tenant_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'remarks': 'remarks',
        'is_default': 'isDefault',
        'extra_properties': 'extraProperties',
        'creation_time': 'creationTime',
        'creator_id': 'creatorId',
        'tenant_id': 'tenantId'
    }

    def __init__(self, id=None, name=None, remarks=None, is_default=None, extra_properties=None, creation_time=None, creator_id=None, tenant_id=None, local_vars_configuration=None):  # noqa: E501
        """RoleDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._remarks = None
        self._is_default = None
        self._extra_properties = None
        self._creation_time = None
        self._creator_id = None
        self._tenant_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        self.remarks = remarks
        if is_default is not None:
            self.is_default = is_default
        self.extra_properties = extra_properties
        if creation_time is not None:
            self.creation_time = creation_time
        self.creator_id = creator_id
        self.tenant_id = tenant_id

    @property
    def id(self):
        """Gets the id of this RoleDto.  # noqa: E501

        角色ID role id  # noqa: E501

        :return: The id of this RoleDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RoleDto.

        角色ID role id  # noqa: E501

        :param id: The id of this RoleDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this RoleDto.  # noqa: E501

        角色名称 role name  # noqa: E501

        :return: The name of this RoleDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RoleDto.

        角色名称 role name  # noqa: E501

        :param name: The name of this RoleDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def remarks(self):
        """Gets the remarks of this RoleDto.  # noqa: E501

        角色备注 role remark  # noqa: E501

        :return: The remarks of this RoleDto.  # noqa: E501
        :rtype: str
        """
        return self._remarks

    @remarks.setter
    def remarks(self, remarks):
        """Sets the remarks of this RoleDto.

        角色备注 role remark  # noqa: E501

        :param remarks: The remarks of this RoleDto.  # noqa: E501
        :type: str
        """

        self._remarks = remarks

    @property
    def is_default(self):
        """Gets the is_default of this RoleDto.  # noqa: E501

        是否为默认角色 if it is the default role  # noqa: E501

        :return: The is_default of this RoleDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this RoleDto.

        是否为默认角色 if it is the default role  # noqa: E501

        :param is_default: The is_default of this RoleDto.  # noqa: E501
        :type: bool
        """

        self._is_default = is_default

    @property
    def extra_properties(self):
        """Gets the extra_properties of this RoleDto.  # noqa: E501

        额外的属性 extra properties  # noqa: E501

        :return: The extra_properties of this RoleDto.  # noqa: E501
        :rtype: str
        """
        return self._extra_properties

    @extra_properties.setter
    def extra_properties(self, extra_properties):
        """Sets the extra_properties of this RoleDto.

        额外的属性 extra properties  # noqa: E501

        :param extra_properties: The extra_properties of this RoleDto.  # noqa: E501
        :type: str
        """

        self._extra_properties = extra_properties

    @property
    def creation_time(self):
        """Gets the creation_time of this RoleDto.  # noqa: E501

        创建时间 create time  # noqa: E501

        :return: The creation_time of this RoleDto.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this RoleDto.

        创建时间 create time  # noqa: E501

        :param creation_time: The creation_time of this RoleDto.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def creator_id(self):
        """Gets the creator_id of this RoleDto.  # noqa: E501

        创建者ID creator id  # noqa: E501

        :return: The creator_id of this RoleDto.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this RoleDto.

        创建者ID creator id  # noqa: E501

        :param creator_id: The creator_id of this RoleDto.  # noqa: E501
        :type: str
        """

        self._creator_id = creator_id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this RoleDto.  # noqa: E501

        租户ID tenant id  # noqa: E501

        :return: The tenant_id of this RoleDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this RoleDto.

        租户ID tenant id  # noqa: E501

        :param tenant_id: The tenant_id of this RoleDto.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RoleDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RoleDto):
            return True

        return self.to_dict() != other.to_dict()
