# coding: utf-8

# flake8: noqa
"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from dhicn_model_information_service.models.add_control_ts_dto import AddControlTsDto
from dhicn_model_information_service.models.add_control_ts_input import AddControlTsInput
from dhicn_model_information_service.models.add_curve_relation_ts_dto import AddCurveRelationTsDto
from dhicn_model_information_service.models.add_curve_relation_ts_input import AddCurveRelationTsInput
from dhicn_model_information_service.models.add_demand_dto import AddDemandDto
from dhicn_model_information_service.models.add_demand_input import AddDemandInput
from dhicn_model_information_service.models.add_flushing_para_dto import AddFlushingParaDto
from dhicn_model_information_service.models.add_flushing_para_input import AddFlushingParaInput
from dhicn_model_information_service.models.add_junction_dto import AddJunctionDto
from dhicn_model_information_service.models.add_junction_input import AddJunctionInput
from dhicn_model_information_service.models.add_pattern_ts_dto import AddPatternTsDto
from dhicn_model_information_service.models.add_pattern_ts_input import AddPatternTsInput
from dhicn_model_information_service.models.add_pipe_dto import AddPipeDto
from dhicn_model_information_service.models.add_pipe_input import AddPipeInput
from dhicn_model_information_service.models.add_pump_dto import AddPumpDto
from dhicn_model_information_service.models.add_pump_input import AddPumpInput
from dhicn_model_information_service.models.add_tank_dto import AddTankDto
from dhicn_model_information_service.models.add_tank_input import AddTankInput
from dhicn_model_information_service.models.add_valve_dto import AddValveDto
from dhicn_model_information_service.models.add_valve_input import AddValveInput
from dhicn_model_information_service.models.boundary_condition_json import BoundaryConditionJson
from dhicn_model_information_service.models.control_rule_info import ControlRuleInfo
from dhicn_model_information_service.models.control_ts_dto import ControlTsDto
from dhicn_model_information_service.models.create_manual_scenario_input import CreateManualScenarioInput
from dhicn_model_information_service.models.create_scene_scenario_input import CreateSceneScenarioInput
from dhicn_model_information_service.models.create_schedule_scenario_input import CreateScheduleScenarioInput
from dhicn_model_information_service.models.cs_pump import CsPump
from dhicn_model_information_service.models.cs_valve import CsValve
from dhicn_model_information_service.models.curve_relation_ts_dto import CurveRelationTsDto
from dhicn_model_information_service.models.da_condition_dto import DaConditionDto
from dhicn_model_information_service.models.delete_control_ts_input import DeleteControlTsInput
from dhicn_model_information_service.models.delete_curve_relation_ts_input import DeleteCurveRelationTsInput
from dhicn_model_information_service.models.delete_da_condition_input import DeleteDaConditionInput
from dhicn_model_information_service.models.delete_flushing_para_input import DeleteFlushingParaInput
from dhicn_model_information_service.models.delete_input import DeleteInput
from dhicn_model_information_service.models.delete_pattern_ts_input import DeletePatternTsInput
from dhicn_model_information_service.models.delete_scenario_input import DeleteScenarioInput
from dhicn_model_information_service.models.flushing_para_dto import FlushingParaDto
from dhicn_model_information_service.models.get_all_boundarys_output import GetAllBoundarysOutput
from dhicn_model_information_service.models.get_boundary_ts_output import GetBoundaryTsOutput
from dhicn_model_information_service.models.get_control_rule_by_scenario_output import GetControlRuleByScenarioOutput
from dhicn_model_information_service.models.get_control_ts_listy_model_id_input import GetControlTsListyModelIdInput
from dhicn_model_information_service.models.get_curve_relation_ts_listy_model_id_input import GetCurveRelationTsListyModelIdInput
from dhicn_model_information_service.models.get_initial_condition_output import GetInitialConditionOutput
from dhicn_model_information_service.models.get_pattern_ts_listy_model_id_input import GetPatternTsListyModelIdInput
from dhicn_model_information_service.models.get_waste_water_condition_output import GetWasteWaterConditionOutput
from dhicn_model_information_service.models.initial_condition import InitialCondition
from dhicn_model_information_service.models.model_process_boundary_condition_document import ModelProcessBoundaryConditionDocument
from dhicn_model_information_service.models.operate_enum import OperateEnum
from dhicn_model_information_service.models.pattern_info import PatternInfo
from dhicn_model_information_service.models.pattern_ts_dto import PatternTsDto
from dhicn_model_information_service.models.pattern_type_enum import PatternTypeEnum
from dhicn_model_information_service.models.query_da_condition_output import QueryDaConditionOutput
from dhicn_model_information_service.models.query_demand_dto import QueryDemandDto
from dhicn_model_information_service.models.query_initial_data_output import QueryInitialDataOutput
from dhicn_model_information_service.models.query_junction_dto import QueryJunctionDto
from dhicn_model_information_service.models.query_pipe_dto import QueryPipeDto
from dhicn_model_information_service.models.query_pump_dto import QueryPumpDto
from dhicn_model_information_service.models.query_tank_dto import QueryTankDto
from dhicn_model_information_service.models.query_valve_dto import QueryValveDto
from dhicn_model_information_service.models.remote_service_error_info import RemoteServiceErrorInfo
from dhicn_model_information_service.models.remote_service_error_response import RemoteServiceErrorResponse
from dhicn_model_information_service.models.remote_service_validation_error_info import RemoteServiceValidationErrorInfo
from dhicn_model_information_service.models.river_gate import RiverGate
from dhicn_model_information_service.models.river_pump import RiverPump
from dhicn_model_information_service.models.save_batch_scenario_to_experience_input import SaveBatchScenarioToExperienceInput
from dhicn_model_information_service.models.save_da_condition_input import SaveDaConditionInput
from dhicn_model_information_service.models.save_initial_data_input import SaveInitialDataInput
from dhicn_model_information_service.models.save_scenario_to_experience_input import SaveScenarioToExperienceInput
from dhicn_model_information_service.models.scenario_info import ScenarioInfo
from dhicn_model_information_service.models.tenant_info import TenantInfo
from dhicn_model_information_service.models.ts_pairs import TsPairs
from dhicn_model_information_service.models.update_boundary_ts_input import UpdateBoundaryTsInput
from dhicn_model_information_service.models.update_control_rule_input import UpdateControlRuleInput
from dhicn_model_information_service.models.update_control_ts_input import UpdateControlTsInput
from dhicn_model_information_service.models.update_curve_relation_ts_input import UpdateCurveRelationTsInput
from dhicn_model_information_service.models.update_demand_dto import UpdateDemandDto
from dhicn_model_information_service.models.update_demand_input import UpdateDemandInput
from dhicn_model_information_service.models.update_flushing_para_input import UpdateFlushingParaInput
from dhicn_model_information_service.models.update_initial_condition_input import UpdateInitialConditionInput
from dhicn_model_information_service.models.update_junction_dto import UpdateJunctionDto
from dhicn_model_information_service.models.update_junction_input import UpdateJunctionInput
from dhicn_model_information_service.models.update_pattern_ts_input import UpdatePatternTsInput
from dhicn_model_information_service.models.update_pipe_dto import UpdatePipeDto
from dhicn_model_information_service.models.update_pipe_input import UpdatePipeInput
from dhicn_model_information_service.models.update_pump_dto import UpdatePumpDto
from dhicn_model_information_service.models.update_pump_input import UpdatePumpInput
from dhicn_model_information_service.models.update_tank_dto import UpdateTankDto
from dhicn_model_information_service.models.update_tank_input import UpdateTankInput
from dhicn_model_information_service.models.update_valve_dto import UpdateValveDto
from dhicn_model_information_service.models.update_valve_input import UpdateValveInput
from dhicn_model_information_service.models.update_wast_water_condition_input import UpdateWastWaterConditionInput
from dhicn_model_information_service.models.waste_water_info import WasteWaterInfo
from dhicn_model_information_service.models.wd_valve_setting_no import WdValveSettingNo
from dhicn_model_information_service.models.wd_valve_status_no import WdValveStatusNo
from dhicn_model_information_service.models.wd_valve_type_no import WdValveTypeNo
