# coding: utf-8

# flake8: noqa

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from dhicn_result_analysis_service.api.catchment_api import CatchmentApi
from dhicn_result_analysis_service.api.log_simulation_api import LogSimulationApi
from dhicn_result_analysis_service.api.m2_d_api import M2DApi
from dhicn_result_analysis_service.api.network_api import NetworkApi
from dhicn_result_analysis_service.api.rain_log_api import RainLogApi
from dhicn_result_analysis_service.api.river_api import RiverApi
from dhicn_result_analysis_service.api.scenario_api import ScenarioApi
from dhicn_result_analysis_service.api.urban_cs_result_analysis_api import UrbanCsResultAnalysisApi
from dhicn_result_analysis_service.api.urban_flooding_api import UrbanFloodingApi
from dhicn_result_analysis_service.api.urban_wd_result_analysis_api import UrbanWdResultAnalysisApi
from dhicn_result_analysis_service.api.urban_wd_time_series_api import UrbanWdTimeSeriesApi
from dhicn_result_analysis_service.api.wd_test_api import WDTestApi
from dhicn_result_analysis_service.api.wq_test_api import WQTestApi
from dhicn_result_analysis_service.api.water_hammer_result_analysis_api import WaterHammerResultAnalysisApi
from dhicn_result_analysis_service.api.wq_result_analysis_api import WqResultAnalysisApi

# import ApiClient
from dhicn_result_analysis_service.api_client import ApiClient
from dhicn_result_analysis_service.configuration import Configuration
from dhicn_result_analysis_service.exceptions import OpenApiException
from dhicn_result_analysis_service.exceptions import ApiTypeError
from dhicn_result_analysis_service.exceptions import ApiValueError
from dhicn_result_analysis_service.exceptions import ApiKeyError
from dhicn_result_analysis_service.exceptions import ApiException
# import models into sdk package
from dhicn_result_analysis_service.models.base_dynamic_output import BaseDynamicOutput
from dhicn_result_analysis_service.models.base_static_output import BaseStaticOutput
from dhicn_result_analysis_service.models.base_timeseries_batch_output import BaseTimeseriesBatchOutput
from dhicn_result_analysis_service.models.base_timeseries_output import BaseTimeseriesOutput
from dhicn_result_analysis_service.models.cs_current_model_output import CsCurrentModelOutput
from dhicn_result_analysis_service.models.cs_history_model_output import CsHistoryModelOutput
from dhicn_result_analysis_service.models.data_type_enum import DataTypeEnum
from dhicn_result_analysis_service.models.filter_condition_enum import FilterConditionEnum
from dhicn_result_analysis_service.models.filter_model_result_dto import FilterModelResultDto
from dhicn_result_analysis_service.models.flooding_risk_info import FloodingRiskInfo
from dhicn_result_analysis_service.models.flooding_risk_item import FloodingRiskItem
from dhicn_result_analysis_service.models.flushing_result_entity import FlushingResultEntity
from dhicn_result_analysis_service.models.gate_info import GateInfo
from dhicn_result_analysis_service.models.gate_statistic_info import GateStatisticInfo
from dhicn_result_analysis_service.models.gate_statistics_output import GateStatisticsOutput
from dhicn_result_analysis_service.models.geo_point_item import GeoPointItem
from dhicn_result_analysis_service.models.get_filter_model_result_input import GetFilterModelResultInput
from dhicn_result_analysis_service.models.get_statistic_result_input import GetStatisticResultInput
from dhicn_result_analysis_service.models.get_time_statistic_result_input import GetTimeStatisticResultInput
from dhicn_result_analysis_service.models.log_simulation_item import LogSimulationItem
from dhicn_result_analysis_service.models.m2_d_by_range_time_input import M2DByRangeTimeInput
from dhicn_result_analysis_service.models.m2_d_data_type_enum import M2DDataTypeEnum
from dhicn_result_analysis_service.models.m2_d_statistic_type_enum import M2DStatisticTypeEnum
from dhicn_result_analysis_service.models.model_result_branch_affected_info_output import ModelResultBranchAffectedInfoOutput
from dhicn_result_analysis_service.models.model_result_pipe_dispatch_statistic_output import ModelResultPipeDispatchStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_pump_statistic_output import ModelResultPipePumpStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_pump_volume_statistic_output import ModelResultPipePumpVolumeStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_sewage_plant_avg_statistic_output import ModelResultPipeSewagePlantAvgStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_sewage_plant_instant_statistic_output import ModelResultPipeSewagePlantInstantStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_sewage_plant_statistic_output import ModelResultPipeSewagePlantStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_smart_well_over_flow_statistic_output import ModelResultPipeSmartWellOverFlowStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_smart_well_statistic_output import ModelResultPipeSmartWellStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_smart_well_total_load_statistic_output import ModelResultPipeSmartWellTotalLoadStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_storage_statistic_output import ModelResultPipeStorageStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_valve_statistic_output import ModelResultPipeValveStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_w_qs_output import ModelResultPipeWQsOutput
from dhicn_result_analysis_service.models.model_result_pipe_wq_input import ModelResultPipeWqInput
from dhicn_result_analysis_service.models.model_result_pipe_wq_output import ModelResultPipeWqOutput
from dhicn_result_analysis_service.models.model_result_river_control_statistic_output import ModelResultRiverControlStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_dam_statistic_output import ModelResultRiverDamStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_gate_pump_statistic_output import ModelResultRiverGatePumpStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_gate_statistic_output import ModelResultRiverGateStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_gate_total_statistic_output import ModelResultRiverGateTotalStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_pump_statistic_output import ModelResultRiverPumpStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_pump_total_statistic_output import ModelResultRiverPumpTotalStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_qualified_statistic_output import ModelResultRiverQualifiedStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_w_qs_output import ModelResultRiverWQsOutput
from dhicn_result_analysis_service.models.model_result_river_wq_input import ModelResultRiverWqInput
from dhicn_result_analysis_service.models.model_result_river_wq_output import ModelResultRiverWqOutput
from dhicn_result_analysis_service.models.model_result_river_wq_statistic_output import ModelResultRiverWqStatisticOutput
from dhicn_result_analysis_service.models.model_result_station_wq_statistic_input import ModelResultStationWqStatisticInput
from dhicn_result_analysis_service.models.model_result_station_wq_statistic_output import ModelResultStationWqStatisticOutput
from dhicn_result_analysis_service.models.model_result_times_output import ModelResultTimesOutput
from dhicn_result_analysis_service.models.model_result_wq_timeseries_input import ModelResultWqTimeseriesInput
from dhicn_result_analysis_service.models.model_result_wq_timeseries_output import ModelResultWqTimeseriesOutput
from dhicn_result_analysis_service.models.model_state_enum import ModelStateEnum
from dhicn_result_analysis_service.models.network_node_static_type_enum import NetworkNodeStaticTypeEnum
from dhicn_result_analysis_service.models.network_profile import NetworkProfile
from dhicn_result_analysis_service.models.network_statistics_output import NetworkStatisticsOutput
from dhicn_result_analysis_service.models.node_data_type_enum import NodeDataTypeEnum
from dhicn_result_analysis_service.models.node_item import NodeItem
from dhicn_result_analysis_service.models.node_profile_data import NodeProfileData
from dhicn_result_analysis_service.models.node_profile_data_profile_data_item import NodeProfileDataProfileDataItem
from dhicn_result_analysis_service.models.node_type_enum import NodeTypeEnum
from dhicn_result_analysis_service.models.object_id import ObjectId
from dhicn_result_analysis_service.models.outlet_result import OutletResult
from dhicn_result_analysis_service.models.overflow_statistics_item import OverflowStatisticsItem
from dhicn_result_analysis_service.models.pipe_data_type_enum import PipeDataTypeEnum
from dhicn_result_analysis_service.models.pipe_profile_item import PipeProfileItem
from dhicn_result_analysis_service.models.pipe_result import PipeResult
from dhicn_result_analysis_service.models.pump_info import PumpInfo
from dhicn_result_analysis_service.models.pump_statistic_info import PumpStatisticInfo
from dhicn_result_analysis_service.models.pump_statistics_output import PumpStatisticsOutput
from dhicn_result_analysis_service.models.pump_volume import PumpVolume
from dhicn_result_analysis_service.models.query_rain_output import QueryRainOutput
from dhicn_result_analysis_service.models.rainfall_runoff_summary_output import RainfallRunoffSummaryOutput
from dhicn_result_analysis_service.models.rainfall_status_enum import RainfallStatusEnum
from dhicn_result_analysis_service.models.remote_service_error_info import RemoteServiceErrorInfo
from dhicn_result_analysis_service.models.remote_service_error_response import RemoteServiceErrorResponse
from dhicn_result_analysis_service.models.remote_service_validation_error_info import RemoteServiceValidationErrorInfo
from dhicn_result_analysis_service.models.river_data_type_enum import RiverDataTypeEnum
from dhicn_result_analysis_service.models.river_profile import RiverProfile
from dhicn_result_analysis_service.models.river_water_level import RiverWaterLevel
from dhicn_result_analysis_service.models.river_water_level_profile_data_item import RiverWaterLevelProfileDataItem
from dhicn_result_analysis_service.models.rr_summary_per_catchment import RrSummaryPerCatchment
from dhicn_result_analysis_service.models.scenario_time_info import ScenarioTimeInfo
from dhicn_result_analysis_service.models.sensitive_points_statistic import SensitivePointsStatistic
from dhicn_result_analysis_service.models.sensitive_points_timeseries import SensitivePointsTimeseries
from dhicn_result_analysis_service.models.smart_well_valve_ts_data import SmartWellValveTsData
from dhicn_result_analysis_service.models.statistic_model_id_item_dto import StatisticModelIdItemDto
from dhicn_result_analysis_service.models.statistic_time_item_dto import StatisticTimeItemDto
from dhicn_result_analysis_service.models.statistic_type_enum import StatisticTypeEnum
from dhicn_result_analysis_service.models.statistics_model_id_result_dto import StatisticsModelIdResultDto
from dhicn_result_analysis_service.models.statistics_time_result_dto import StatisticsTimeResultDto
from dhicn_result_analysis_service.models.storage_data import StorageData
from dhicn_result_analysis_service.models.string_page import StringPage
from dhicn_result_analysis_service.models.structure_type_enum import StructureTypeEnum
from dhicn_result_analysis_service.models.structures_item_enum import StructuresItemEnum
from dhicn_result_analysis_service.models.sys_wd_data_type_enum import SysWdDataTypeEnum
from dhicn_result_analysis_service.models.trace_wq_close_pipe import TraceWqClosePipe
from dhicn_result_analysis_service.models.trace_wq_close_pipe_result import TraceWqClosePipeResult
from dhicn_result_analysis_service.models.trace_wq_valve_info import TraceWqValveInfo
from dhicn_result_analysis_service.models.ts_pair_object import TsPairObject
from dhicn_result_analysis_service.models.ts_pairs import TsPairs
from dhicn_result_analysis_service.models.user_info import UserInfo
from dhicn_result_analysis_service.models.valve_statistic_list import ValveStatisticList
from dhicn_result_analysis_service.models.valve_statistics_output import ValveStatisticsOutput
from dhicn_result_analysis_service.models.wd_batch_structure_timeseries_input import WdBatchStructureTimeseriesInput
from dhicn_result_analysis_service.models.wd_batch_timeseries_input import WdBatchTimeseriesInput
from dhicn_result_analysis_service.models.wd_calculate_type_enum import WdCalculateTypeEnum
from dhicn_result_analysis_service.models.wd_data_type_enum import WdDataTypeEnum
from dhicn_result_analysis_service.models.wd_feature_type_enum import WdFeatureTypeEnum
from dhicn_result_analysis_service.models.wd_history_model_input import WdHistoryModelInput
from dhicn_result_analysis_service.models.wd_history_model_output import WdHistoryModelOutput
from dhicn_result_analysis_service.models.wd_statistic_shut_off_user_dto import WdStatisticShutOffUserDto
from dhicn_result_analysis_service.models.wd_zone_model_result_input import WdZoneModelResultInput
from dhicn_result_analysis_service.models.wd_zone_model_result_output import WdZoneModelResultOutput
from dhicn_result_analysis_service.models.wq_info_value import WqInfoValue
from dhicn_result_analysis_service.models.wq_instant_statistic_info import WqInstantStatisticInfo
from dhicn_result_analysis_service.models.wq_load_info import WqLoadInfo
from dhicn_result_analysis_service.models.wq_max_statistic import WqMaxStatistic
from dhicn_result_analysis_service.models.wq_statistic import WqStatistic
from dhicn_result_analysis_service.models.wq_value_info import WqValueInfo

