# coding: utf-8

"""
    wwtp-paas-infrastructure-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_infrastructure_service.configuration import Configuration


class ModelNodeConfigInputOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'node_code': 'str',
        'node_name': 'str',
        'unit': 'str',
        'data_type': 'str',
        'model_name': 'str'
    }

    attribute_map = {
        'node_code': 'nodeCode',
        'node_name': 'nodeName',
        'unit': 'unit',
        'data_type': 'dataType',
        'model_name': 'modelName'
    }

    def __init__(self, node_code=None, node_name=None, unit=None, data_type=None, model_name=None, local_vars_configuration=None):  # noqa: E501
        """ModelNodeConfigInputOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._node_code = None
        self._node_name = None
        self._unit = None
        self._data_type = None
        self._model_name = None
        self.discriminator = None

        self.node_code = node_code
        self.node_name = node_name
        self.unit = unit
        self.data_type = data_type
        self.model_name = model_name

    @property
    def node_code(self):
        """Gets the node_code of this ModelNodeConfigInputOutput.  # noqa: E501

        模型点位编码 model node code  # noqa: E501

        :return: The node_code of this ModelNodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_code

    @node_code.setter
    def node_code(self, node_code):
        """Sets the node_code of this ModelNodeConfigInputOutput.

        模型点位编码 model node code  # noqa: E501

        :param node_code: The node_code of this ModelNodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._node_code = node_code

    @property
    def node_name(self):
        """Gets the node_name of this ModelNodeConfigInputOutput.  # noqa: E501

        模型点位名称 mode node name  # noqa: E501

        :return: The node_name of this ModelNodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_name

    @node_name.setter
    def node_name(self, node_name):
        """Sets the node_name of this ModelNodeConfigInputOutput.

        模型点位名称 mode node name  # noqa: E501

        :param node_name: The node_name of this ModelNodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._node_name = node_name

    @property
    def unit(self):
        """Gets the unit of this ModelNodeConfigInputOutput.  # noqa: E501

        单位 data unit  # noqa: E501

        :return: The unit of this ModelNodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this ModelNodeConfigInputOutput.

        单位 data unit  # noqa: E501

        :param unit: The unit of this ModelNodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def data_type(self):
        """Gets the data_type of this ModelNodeConfigInputOutput.  # noqa: E501

        数据类型，如负荷、浓度等 data type like Load, Concentration, etc.  # noqa: E501

        :return: The data_type of this ModelNodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this ModelNodeConfigInputOutput.

        数据类型，如负荷、浓度等 data type like Load, Concentration, etc.  # noqa: E501

        :param data_type: The data_type of this ModelNodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    @property
    def model_name(self):
        """Gets the model_name of this ModelNodeConfigInputOutput.  # noqa: E501

        模板模型名称（即模板方案名称） template model name  # noqa: E501

        :return: The model_name of this ModelNodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this ModelNodeConfigInputOutput.

        模板模型名称（即模板方案名称） template model name  # noqa: E501

        :param model_name: The model_name of this ModelNodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelNodeConfigInputOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelNodeConfigInputOutput):
            return True

        return self.to_dict() != other.to_dict()
