# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class OrganizationWithUserStatusInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'level_code': 'str',
        'parent_level_code': 'str',
        'users': 'list[UserInfoWithStatus]',
        'is_has_children': 'bool',
        'children': 'list[OrganizationWithUserStatusInfo]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'level_code': 'levelCode',
        'parent_level_code': 'parentLevelCode',
        'users': 'users',
        'is_has_children': 'isHasChildren',
        'children': 'children'
    }

    def __init__(self, id=None, name=None, level_code=None, parent_level_code=None, users=None, is_has_children=None, children=None, local_vars_configuration=None):  # noqa: E501
        """OrganizationWithUserStatusInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._level_code = None
        self._parent_level_code = None
        self._users = None
        self._is_has_children = None
        self._children = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        self.level_code = level_code
        self.parent_level_code = parent_level_code
        self.users = users
        if is_has_children is not None:
            self.is_has_children = is_has_children
        self.children = children

    @property
    def id(self):
        """Gets the id of this OrganizationWithUserStatusInfo.  # noqa: E501


        :return: The id of this OrganizationWithUserStatusInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrganizationWithUserStatusInfo.


        :param id: The id of this OrganizationWithUserStatusInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this OrganizationWithUserStatusInfo.  # noqa: E501


        :return: The name of this OrganizationWithUserStatusInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrganizationWithUserStatusInfo.


        :param name: The name of this OrganizationWithUserStatusInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def level_code(self):
        """Gets the level_code of this OrganizationWithUserStatusInfo.  # noqa: E501


        :return: The level_code of this OrganizationWithUserStatusInfo.  # noqa: E501
        :rtype: str
        """
        return self._level_code

    @level_code.setter
    def level_code(self, level_code):
        """Sets the level_code of this OrganizationWithUserStatusInfo.


        :param level_code: The level_code of this OrganizationWithUserStatusInfo.  # noqa: E501
        :type: str
        """

        self._level_code = level_code

    @property
    def parent_level_code(self):
        """Gets the parent_level_code of this OrganizationWithUserStatusInfo.  # noqa: E501


        :return: The parent_level_code of this OrganizationWithUserStatusInfo.  # noqa: E501
        :rtype: str
        """
        return self._parent_level_code

    @parent_level_code.setter
    def parent_level_code(self, parent_level_code):
        """Sets the parent_level_code of this OrganizationWithUserStatusInfo.


        :param parent_level_code: The parent_level_code of this OrganizationWithUserStatusInfo.  # noqa: E501
        :type: str
        """

        self._parent_level_code = parent_level_code

    @property
    def users(self):
        """Gets the users of this OrganizationWithUserStatusInfo.  # noqa: E501


        :return: The users of this OrganizationWithUserStatusInfo.  # noqa: E501
        :rtype: list[UserInfoWithStatus]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this OrganizationWithUserStatusInfo.


        :param users: The users of this OrganizationWithUserStatusInfo.  # noqa: E501
        :type: list[UserInfoWithStatus]
        """

        self._users = users

    @property
    def is_has_children(self):
        """Gets the is_has_children of this OrganizationWithUserStatusInfo.  # noqa: E501


        :return: The is_has_children of this OrganizationWithUserStatusInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_has_children

    @is_has_children.setter
    def is_has_children(self, is_has_children):
        """Sets the is_has_children of this OrganizationWithUserStatusInfo.


        :param is_has_children: The is_has_children of this OrganizationWithUserStatusInfo.  # noqa: E501
        :type: bool
        """

        self._is_has_children = is_has_children

    @property
    def children(self):
        """Gets the children of this OrganizationWithUserStatusInfo.  # noqa: E501


        :return: The children of this OrganizationWithUserStatusInfo.  # noqa: E501
        :rtype: list[OrganizationWithUserStatusInfo]
        """
        return self._children

    @children.setter
    def children(self, children):
        """Sets the children of this OrganizationWithUserStatusInfo.


        :param children: The children of this OrganizationWithUserStatusInfo.  # noqa: E501
        :type: list[OrganizationWithUserStatusInfo]
        """

        self._children = children

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrganizationWithUserStatusInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrganizationWithUserStatusInfo):
            return True

        return self.to_dict() != other.to_dict()
