# coding: utf-8

"""
    digital-twin-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_digital_twin_service.configuration import Configuration


class AttributeConditionInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'attribute_key': 'str',
        'attribute_value': 'str',
        'data_type': 'int'
    }

    attribute_map = {
        'attribute_key': 'attributeKey',
        'attribute_value': 'attributeValue',
        'data_type': 'dataType'
    }

    def __init__(self, attribute_key=None, attribute_value=None, data_type=None, local_vars_configuration=None):  # noqa: E501
        """AttributeConditionInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._attribute_key = None
        self._attribute_value = None
        self._data_type = None
        self.discriminator = None

        self.attribute_key = attribute_key
        self.attribute_value = attribute_value
        self.data_type = data_type

    @property
    def attribute_key(self):
        """Gets the attribute_key of this AttributeConditionInput.  # noqa: E501

        模型中的ID列表，可为空 model muid list, can be empty  # noqa: E501

        :return: The attribute_key of this AttributeConditionInput.  # noqa: E501
        :rtype: str
        """
        return self._attribute_key

    @attribute_key.setter
    def attribute_key(self, attribute_key):
        """Sets the attribute_key of this AttributeConditionInput.

        模型中的ID列表，可为空 model muid list, can be empty  # noqa: E501

        :param attribute_key: The attribute_key of this AttributeConditionInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and attribute_key is None:  # noqa: E501
            raise ValueError("Invalid value for `attribute_key`, must not be `None`")  # noqa: E501

        self._attribute_key = attribute_key

    @property
    def attribute_value(self):
        """Gets the attribute_value of this AttributeConditionInput.  # noqa: E501

        属性值  # noqa: E501

        :return: The attribute_value of this AttributeConditionInput.  # noqa: E501
        :rtype: str
        """
        return self._attribute_value

    @attribute_value.setter
    def attribute_value(self, attribute_value):
        """Sets the attribute_value of this AttributeConditionInput.

        属性值  # noqa: E501

        :param attribute_value: The attribute_value of this AttributeConditionInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and attribute_value is None:  # noqa: E501
            raise ValueError("Invalid value for `attribute_value`, must not be `None`")  # noqa: E501

        self._attribute_value = attribute_value

    @property
    def data_type(self):
        """Gets the data_type of this AttributeConditionInput.  # noqa: E501

        0-StrValue 1-BoolValue 2-LongValue 3-DblValue 4-JsonValue 5-DateTimeValue   # noqa: E501

        :return: The data_type of this AttributeConditionInput.  # noqa: E501
        :rtype: int
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this AttributeConditionInput.

        0-StrValue 1-BoolValue 2-LongValue 3-DblValue 4-JsonValue 5-DateTimeValue   # noqa: E501

        :param data_type: The data_type of this AttributeConditionInput.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and data_type is None:  # noqa: E501
            raise ValueError("Invalid value for `data_type`, must not be `None`")  # noqa: E501
        allowed_values = [0, 1, 2, 3, 4, 5]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and data_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `data_type` ({0}), must be one of {1}"  # noqa: E501
                .format(data_type, allowed_values)
            )

        self._data_type = data_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttributeConditionInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AttributeConditionInput):
            return True

        return self.to_dict() != other.to_dict()
