# coding: utf-8

"""
    wwtp-paas-infrastructure-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_infrastructure_service.configuration import Configuration


class TemplateOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'model_name': 'str',
        'model_type': 'int',
        'model_file_name': 'str',
        'create_time': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'model_name': 'modelName',
        'model_type': 'modelType',
        'model_file_name': 'modelFileName',
        'create_time': 'createTime'
    }

    def __init__(self, id=None, model_name=None, model_type=None, model_file_name=None, create_time=None, local_vars_configuration=None):  # noqa: E501
        """TemplateOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._model_name = None
        self._model_type = None
        self._model_file_name = None
        self._create_time = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.model_name = model_name
        if model_type is not None:
            self.model_type = model_type
        self.model_file_name = model_file_name
        if create_time is not None:
            self.create_time = create_time

    @property
    def id(self):
        """Gets the id of this TemplateOutput.  # noqa: E501

        模板方案ID template scenario id  # noqa: E501

        :return: The id of this TemplateOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TemplateOutput.

        模板方案ID template scenario id  # noqa: E501

        :param id: The id of this TemplateOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def model_name(self):
        """Gets the model_name of this TemplateOutput.  # noqa: E501

        模型名称（即模板方案名称） model name as well as template scenario name  # noqa: E501

        :return: The model_name of this TemplateOutput.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this TemplateOutput.

        模型名称（即模板方案名称） model name as well as template scenario name  # noqa: E501

        :param model_name: The model_name of this TemplateOutput.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    @property
    def model_type(self):
        """Gets the model_type of this TemplateOutput.  # noqa: E501

        模型类型，分为WWTP, WWTPOptim, WWTPMLab model type including WWTP, WWTPOptim, WWTPMLab  # noqa: E501

        :return: The model_type of this TemplateOutput.  # noqa: E501
        :rtype: int
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """Sets the model_type of this TemplateOutput.

        模型类型，分为WWTP, WWTPOptim, WWTPMLab model type including WWTP, WWTPOptim, WWTPMLab  # noqa: E501

        :param model_type: The model_type of this TemplateOutput.  # noqa: E501
        :type: int
        """
        allowed_values = [1, 2, 3]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and model_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `model_type` ({0}), must be one of {1}"  # noqa: E501
                .format(model_type, allowed_values)
            )

        self._model_type = model_type

    @property
    def model_file_name(self):
        """Gets the model_file_name of this TemplateOutput.  # noqa: E501

        模板文件名称（压缩文件） compressed model file name  # noqa: E501

        :return: The model_file_name of this TemplateOutput.  # noqa: E501
        :rtype: str
        """
        return self._model_file_name

    @model_file_name.setter
    def model_file_name(self, model_file_name):
        """Sets the model_file_name of this TemplateOutput.

        模板文件名称（压缩文件） compressed model file name  # noqa: E501

        :param model_file_name: The model_file_name of this TemplateOutput.  # noqa: E501
        :type: str
        """

        self._model_file_name = model_file_name

    @property
    def create_time(self):
        """Gets the create_time of this TemplateOutput.  # noqa: E501

        创建时间 create time  # noqa: E501

        :return: The create_time of this TemplateOutput.  # noqa: E501
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this TemplateOutput.

        创建时间 create time  # noqa: E501

        :param create_time: The create_time of this TemplateOutput.  # noqa: E501
        :type: datetime
        """

        self._create_time = create_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TemplateOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TemplateOutput):
            return True

        return self.to_dict() != other.to_dict()
