# coding: utf-8

"""
    digital-twin-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_digital_twin_service.configuration import Configuration


class GetModelIdsOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key_point_id': 'str',
        'model_points': 'list[GetModelPointInfo]'
    }

    attribute_map = {
        'key_point_id': 'keyPointId',
        'model_points': 'modelPoints'
    }

    def __init__(self, key_point_id=None, model_points=None, local_vars_configuration=None):  # noqa: E501
        """GetModelIdsOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._key_point_id = None
        self._model_points = None
        self.discriminator = None

        if key_point_id is not None:
            self.key_point_id = key_point_id
        self.model_points = model_points

    @property
    def key_point_id(self):
        """Gets the key_point_id of this GetModelIdsOutput.  # noqa: E501

        关键点位Id key point id  # noqa: E501

        :return: The key_point_id of this GetModelIdsOutput.  # noqa: E501
        :rtype: str
        """
        return self._key_point_id

    @key_point_id.setter
    def key_point_id(self, key_point_id):
        """Sets the key_point_id of this GetModelIdsOutput.

        关键点位Id key point id  # noqa: E501

        :param key_point_id: The key_point_id of this GetModelIdsOutput.  # noqa: E501
        :type: str
        """

        self._key_point_id = key_point_id

    @property
    def model_points(self):
        """Gets the model_points of this GetModelIdsOutput.  # noqa: E501

        模型点位信息 model points  # noqa: E501

        :return: The model_points of this GetModelIdsOutput.  # noqa: E501
        :rtype: list[GetModelPointInfo]
        """
        return self._model_points

    @model_points.setter
    def model_points(self, model_points):
        """Sets the model_points of this GetModelIdsOutput.

        模型点位信息 model points  # noqa: E501

        :param model_points: The model_points of this GetModelIdsOutput.  # noqa: E501
        :type: list[GetModelPointInfo]
        """

        self._model_points = model_points

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetModelIdsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetModelIdsOutput):
            return True

        return self.to_dict() != other.to_dict()
