# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class ModelResultRiverDamStatisticOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'asset_id': 'str',
        'asset_name': 'str',
        'max_water_level': 'float',
        'min_water_level': 'float'
    }

    attribute_map = {
        'asset_id': 'assetID',
        'asset_name': 'assetName',
        'max_water_level': 'maxWaterLevel',
        'min_water_level': 'minWaterLevel'
    }

    def __init__(self, asset_id=None, asset_name=None, max_water_level=None, min_water_level=None, local_vars_configuration=None):  # noqa: E501
        """ModelResultRiverDamStatisticOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._asset_id = None
        self._asset_name = None
        self._max_water_level = None
        self._min_water_level = None
        self.discriminator = None

        self.asset_id = asset_id
        self.asset_name = asset_name
        if max_water_level is not None:
            self.max_water_level = max_water_level
        if min_water_level is not None:
            self.min_water_level = min_water_level

    @property
    def asset_id(self):
        """Gets the asset_id of this ModelResultRiverDamStatisticOutput.  # noqa: E501

        坝id dam id  # noqa: E501

        :return: The asset_id of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :rtype: str
        """
        return self._asset_id

    @asset_id.setter
    def asset_id(self, asset_id):
        """Sets the asset_id of this ModelResultRiverDamStatisticOutput.

        坝id dam id  # noqa: E501

        :param asset_id: The asset_id of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :type: str
        """

        self._asset_id = asset_id

    @property
    def asset_name(self):
        """Gets the asset_name of this ModelResultRiverDamStatisticOutput.  # noqa: E501

        坝名称 dam name  # noqa: E501

        :return: The asset_name of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :rtype: str
        """
        return self._asset_name

    @asset_name.setter
    def asset_name(self, asset_name):
        """Sets the asset_name of this ModelResultRiverDamStatisticOutput.

        坝名称 dam name  # noqa: E501

        :param asset_name: The asset_name of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :type: str
        """

        self._asset_name = asset_name

    @property
    def max_water_level(self):
        """Gets the max_water_level of this ModelResultRiverDamStatisticOutput.  # noqa: E501

        最高控制水位 maximum control water level  # noqa: E501

        :return: The max_water_level of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :rtype: float
        """
        return self._max_water_level

    @max_water_level.setter
    def max_water_level(self, max_water_level):
        """Sets the max_water_level of this ModelResultRiverDamStatisticOutput.

        最高控制水位 maximum control water level  # noqa: E501

        :param max_water_level: The max_water_level of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :type: float
        """

        self._max_water_level = max_water_level

    @property
    def min_water_level(self):
        """Gets the min_water_level of this ModelResultRiverDamStatisticOutput.  # noqa: E501

        最低控制水位 Minimum control water level  # noqa: E501

        :return: The min_water_level of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :rtype: float
        """
        return self._min_water_level

    @min_water_level.setter
    def min_water_level(self, min_water_level):
        """Sets the min_water_level of this ModelResultRiverDamStatisticOutput.

        最低控制水位 Minimum control water level  # noqa: E501

        :param min_water_level: The min_water_level of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :type: float
        """

        self._min_water_level = min_water_level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelResultRiverDamStatisticOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelResultRiverDamStatisticOutput):
            return True

        return self.to_dict() != other.to_dict()
