# coding: utf-8

# flake8: noqa
"""
    scenario-compute-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_dapr_services_dtos_auto_forecast_info import DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_dapr_services_dtos_model_boundary_config_output import DhiDssScenarioComputeDaprServicesDtosModelBoundaryConfigOutput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_dapr_services_dtos_point_express_item import DhiDssScenarioComputeDaprServicesDtosPointExpressItem
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_dapr_services_dtos_run_model_info import DhiDssScenarioComputeDaprServicesDtosRunModelInfo
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_rf_dtos_create_flood_storage_area_scenario_input import DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_rf_dtos_create_schedule_scenario_input import DhiDssScenarioComputeRfDtosCreateScheduleScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_create_auto_scenario_input import DhiDssScenarioComputeScenarioDtosCreateAutoScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_create_manual_scenario_input import DhiDssScenarioComputeScenarioDtosCreateManualScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_create_response_scenario_input import DhiDssScenarioComputeScenarioDtosCreateResponseScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_create_scene_scenario_input import DhiDssScenarioComputeScenarioDtosCreateSceneScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_create_schedule_scenario_input import DhiDssScenarioComputeScenarioDtosCreateScheduleScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_create_wq_accident_scenario_input import DhiDssScenarioComputeScenarioDtosCreateWqAccidentScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_device_indicator_output import DhiDssScenarioComputeScenarioDtosDeviceIndicatorOutput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_scenario_info import DhiDssScenarioComputeScenarioDtosScenarioInfo
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_wd_dtos_create_wd_close_valve_scenario_input import DhiDssScenarioComputeWdDtosCreateWdCloseValveScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_wd_dtos_create_wd_flushing_scenario_input import DhiDssScenarioComputeWdDtosCreateWdFlushingScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_wd_dtos_create_wd_pipe_burst_accident_scenario_input import DhiDssScenarioComputeWdDtosCreateWdPipeBurstAccidentScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_wd_dtos_create_wd_planning_scenario_input import DhiDssScenarioComputeWdDtosCreateWdPlanningScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_wd_dtos_create_wd_schedule_scenario_input import DhiDssScenarioComputeWdDtosCreateWdScheduleScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_wd_dtos_create_wd_water_hammer_scenario_input import DhiDssScenarioComputeWdDtosCreateWdWaterHammerScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_wd_dtos_create_wdwq_accident_scenario_input import DhiDssScenarioComputeWdDtosCreateWdwqAccidentScenarioInput
from dhicn_scenario_compute_service.models.volo_abp_http_remote_service_error_info import VoloAbpHttpRemoteServiceErrorInfo
from dhicn_scenario_compute_service.models.volo_abp_http_remote_service_error_response import VoloAbpHttpRemoteServiceErrorResponse
from dhicn_scenario_compute_service.models.volo_abp_http_remote_service_validation_error_info import VoloAbpHttpRemoteServiceValidationErrorInfo
