from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_result_analysis_service.api.catchment_api import CatchmentApi
from dhicn_result_analysis_service.api.log_simulation_api import LogSimulationApi
from dhicn_result_analysis_service.api.m2_d_api import M2DApi
from dhicn_result_analysis_service.api.network_api import NetworkApi
from dhicn_result_analysis_service.api.rain_log_api import RainLogApi
from dhicn_result_analysis_service.api.river_api import RiverApi
from dhicn_result_analysis_service.api.scenario_api import ScenarioApi
from dhicn_result_analysis_service.api.urban_cs_result_analysis_api import UrbanCsResultAnalysisApi
from dhicn_result_analysis_service.api.urban_flooding_api import UrbanFloodingApi
from dhicn_result_analysis_service.api.urban_wd_result_analysis_api import UrbanWdResultAnalysisApi
from dhicn_result_analysis_service.api.urban_wd_time_series_api import UrbanWdTimeSeriesApi
from dhicn_result_analysis_service.api.wd_test_api import WDTestApi
from dhicn_result_analysis_service.api.wq_test_api import WQTestApi
from dhicn_result_analysis_service.api.water_hammer_result_analysis_api import WaterHammerResultAnalysisApi
from dhicn_result_analysis_service.api.wq_result_analysis_api import WqResultAnalysisApi
