# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class SystemSettingOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'scenario_id': 'str',
        'item_code': 'str',
        'item_name': 'str',
        'type': 'str',
        'value': 'float',
        'sort': 'int',
        'principle_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'scenario_id': 'scenarioId',
        'item_code': 'itemCode',
        'item_name': 'itemName',
        'type': 'type',
        'value': 'value',
        'sort': 'sort',
        'principle_id': 'principleId'
    }

    def __init__(self, id=None, scenario_id=None, item_code=None, item_name=None, type=None, value=None, sort=None, principle_id=None, local_vars_configuration=None):  # noqa: E501
        """SystemSettingOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._scenario_id = None
        self._item_code = None
        self._item_name = None
        self._type = None
        self._value = None
        self._sort = None
        self._principle_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.scenario_id = scenario_id
        self.item_code = item_code
        self.item_name = item_name
        self.type = type
        if value is not None:
            self.value = value
        if sort is not None:
            self.sort = sort
        if principle_id is not None:
            self.principle_id = principle_id

    @property
    def id(self):
        """Gets the id of this SystemSettingOutput.  # noqa: E501


        :return: The id of this SystemSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SystemSettingOutput.


        :param id: The id of this SystemSettingOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def scenario_id(self):
        """Gets the scenario_id of this SystemSettingOutput.  # noqa: E501


        :return: The scenario_id of this SystemSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this SystemSettingOutput.


        :param scenario_id: The scenario_id of this SystemSettingOutput.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def item_code(self):
        """Gets the item_code of this SystemSettingOutput.  # noqa: E501

        信息项编码  # noqa: E501

        :return: The item_code of this SystemSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._item_code

    @item_code.setter
    def item_code(self, item_code):
        """Sets the item_code of this SystemSettingOutput.

        信息项编码  # noqa: E501

        :param item_code: The item_code of this SystemSettingOutput.  # noqa: E501
        :type: str
        """

        self._item_code = item_code

    @property
    def item_name(self):
        """Gets the item_name of this SystemSettingOutput.  # noqa: E501

        信息项  # noqa: E501

        :return: The item_name of this SystemSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._item_name

    @item_name.setter
    def item_name(self, item_name):
        """Sets the item_name of this SystemSettingOutput.

        信息项  # noqa: E501

        :param item_name: The item_name of this SystemSettingOutput.  # noqa: E501
        :type: str
        """

        self._item_name = item_name

    @property
    def type(self):
        """Gets the type of this SystemSettingOutput.  # noqa: E501

        配置的类型，Plan--预案、AutoRun--滚动预报方案  # noqa: E501

        :return: The type of this SystemSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SystemSettingOutput.

        配置的类型，Plan--预案、AutoRun--滚动预报方案  # noqa: E501

        :param type: The type of this SystemSettingOutput.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def value(self):
        """Gets the value of this SystemSettingOutput.  # noqa: E501

        配水原则值  # noqa: E501

        :return: The value of this SystemSettingOutput.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this SystemSettingOutput.

        配水原则值  # noqa: E501

        :param value: The value of this SystemSettingOutput.  # noqa: E501
        :type: float
        """

        self._value = value

    @property
    def sort(self):
        """Gets the sort of this SystemSettingOutput.  # noqa: E501


        :return: The sort of this SystemSettingOutput.  # noqa: E501
        :rtype: int
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this SystemSettingOutput.


        :param sort: The sort of this SystemSettingOutput.  # noqa: E501
        :type: int
        """

        self._sort = sort

    @property
    def principle_id(self):
        """Gets the principle_id of this SystemSettingOutput.  # noqa: E501

        原则ID，将配水算法设置与原则绑定  # noqa: E501

        :return: The principle_id of this SystemSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._principle_id

    @principle_id.setter
    def principle_id(self, principle_id):
        """Sets the principle_id of this SystemSettingOutput.

        原则ID，将配水算法设置与原则绑定  # noqa: E501

        :param principle_id: The principle_id of this SystemSettingOutput.  # noqa: E501
        :type: str
        """

        self._principle_id = principle_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemSettingOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SystemSettingOutput):
            return True

        return self.to_dict() != other.to_dict()
