# coding: utf-8

# flake8: noqa

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from dhicn_wd_domain_service.api.accident_api import AccidentApi
from dhicn_wd_domain_service.api.accuracy_config_api import AccuracyConfigApi
from dhicn_wd_domain_service.api.alarm_config_api import AlarmConfigApi
from dhicn_wd_domain_service.api.alarm_log_api import AlarmLogApi
from dhicn_wd_domain_service.api.document_api import DocumentApi
from dhicn_wd_domain_service.api.gis_api import GISApi
from dhicn_wd_domain_service.api.indicator_config_api import IndicatorConfigApi
from dhicn_wd_domain_service.api.online_api import OnlineApi
from dhicn_wd_domain_service.api.pipe_risk_api import PipeRiskApi
from dhicn_wd_domain_service.api.scenario_compute_api import ScenarioComputeApi
from dhicn_wd_domain_service.api.schedule_api import ScheduleApi
from dhicn_wd_domain_service.api.statistic_api import StatisticApi
from dhicn_wd_domain_service.api.valve_config_api import ValveConfigApi

# import ApiClient
from dhicn_wd_domain_service.api_client import ApiClient
from dhicn_wd_domain_service.configuration import Configuration
from dhicn_wd_domain_service.exceptions import OpenApiException
from dhicn_wd_domain_service.exceptions import ApiTypeError
from dhicn_wd_domain_service.exceptions import ApiValueError
from dhicn_wd_domain_service.exceptions import ApiKeyError
from dhicn_wd_domain_service.exceptions import ApiException
# import models into sdk package
from dhicn_wd_domain_service.models.accuracy_config_dto import AccuracyConfigDto
from dhicn_wd_domain_service.models.add_accuracy_config_input import AddAccuracyConfigInput
from dhicn_wd_domain_service.models.add_alarm_config_input import AddAlarmConfigInput
from dhicn_wd_domain_service.models.add_broken_pipe_risk_para_cfg_input import AddBrokenPipeRiskParaCfgInput
from dhicn_wd_domain_service.models.add_list_alarm_config_input import AddListAlarmConfigInput
from dhicn_wd_domain_service.models.add_pipe_risk_property_input import AddPipeRiskPropertyInput
from dhicn_wd_domain_service.models.add_pipe_risk_weight_input import AddPipeRiskWeightInput
from dhicn_wd_domain_service.models.alarm_config_dto import AlarmConfigDto
from dhicn_wd_domain_service.models.alarm_log_dto import AlarmLogDto
from dhicn_wd_domain_service.models.burst_pipe_valves_item import BurstPipeValvesItem
from dhicn_wd_domain_service.models.close_gis_valve_info import CloseGisValveInfo
from dhicn_wd_domain_service.models.component_detail_info import ComponentDetailInfo
from dhicn_wd_domain_service.models.control_ts_info import ControlTsInfo
from dhicn_wd_domain_service.models.current_online_data import CurrentOnlineData
from dhicn_wd_domain_service.models.current_online_model_data import CurrentOnlineModelData
from dhicn_wd_domain_service.models.curve_info import CurveInfo
from dhicn_wd_domain_service.models.curve_ts_info import CurveTsInfo
from dhicn_wd_domain_service.models.delete_accuracy_config_input import DeleteAccuracyConfigInput
from dhicn_wd_domain_service.models.delete_alarm_config_input import DeleteAlarmConfigInput
from dhicn_wd_domain_service.models.device_detail_info import DeviceDetailInfo
from dhicn_wd_domain_service.models.device_indicator_info import DeviceIndicatorInfo
from dhicn_wd_domain_service.models.device_indicator_para import DeviceIndicatorPara
from dhicn_wd_domain_service.models.device_info import DeviceInfo
from dhicn_wd_domain_service.models.event_detail_info import EventDetailInfo
from dhicn_wd_domain_service.models.find_burst_pipe_valves_batch import FindBurstPipeValvesBatch
from dhicn_wd_domain_service.models.find_burst_pipe_valves_input import FindBurstPipeValvesInput
from dhicn_wd_domain_service.models.get_accuracy_para import GetAccuracyPara
from dhicn_wd_domain_service.models.get_alarm_log_by_type_input import GetAlarmLogByTypeInput
from dhicn_wd_domain_service.models.get_current_data_para import GetCurrentDataPara
from dhicn_wd_domain_service.models.get_online_model_data_para import GetOnlineModelDataPara
from dhicn_wd_domain_service.models.get_valves_by_pipe_ids_input import GetValvesByPipeIdsInput
from dhicn_wd_domain_service.models.gis_valve_info import GisValveInfo
from dhicn_wd_domain_service.models.indicator_info import IndicatorInfo
from dhicn_wd_domain_service.models.indicator_list import IndicatorList
from dhicn_wd_domain_service.models.int32_double_key_value import Int32DoubleKeyValue
from dhicn_wd_domain_service.models.int32_model_pipe_info_list_key_value import Int32ModelPipeInfoListKeyValue
from dhicn_wd_domain_service.models.model_map_assembly_info import ModelMapAssemblyInfo
from dhicn_wd_domain_service.models.model_pipe_info import ModelPipeInfo
from dhicn_wd_domain_service.models.model_point_info import ModelPointInfo
from dhicn_wd_domain_service.models.online_accuracy_data import OnlineAccuracyData
from dhicn_wd_domain_service.models.online_data import OnlineData
from dhicn_wd_domain_service.models.online_model_data import OnlineModelData
from dhicn_wd_domain_service.models.pattern_info import PatternInfo
from dhicn_wd_domain_service.models.pattern_ts_info import PatternTsInfo
from dhicn_wd_domain_service.models.pipe_risk_param_output import PipeRiskParamOutput
from dhicn_wd_domain_service.models.pipe_risk_property_output import PipeRiskPropertyOutput
from dhicn_wd_domain_service.models.pipe_risk_weight_output import PipeRiskWeightOutput
from dhicn_wd_domain_service.models.point_data_type_info import PointDataTypeInfo
from dhicn_wd_domain_service.models.pump_info import PumpInfo
from dhicn_wd_domain_service.models.remote_service_error_info import RemoteServiceErrorInfo
from dhicn_wd_domain_service.models.remote_service_error_response import RemoteServiceErrorResponse
from dhicn_wd_domain_service.models.remote_service_validation_error_info import RemoteServiceValidationErrorInfo
from dhicn_wd_domain_service.models.save_alarm_config_by_type_input import SaveAlarmConfigByTypeInput
from dhicn_wd_domain_service.models.save_close_gis_valve_input import SaveCloseGisValveInput
from dhicn_wd_domain_service.models.save_indicator_config_input import SaveIndicatorConfigInput
from dhicn_wd_domain_service.models.save_pipe_burst_info_input import SavePipeBurstInfoInput
from dhicn_wd_domain_service.models.save_wq_accident_info_input import SaveWqAccidentInfoInput
from dhicn_wd_domain_service.models.scene_detail_info import SceneDetailInfo
from dhicn_wd_domain_service.models.statistic_info import StatisticInfo
from dhicn_wd_domain_service.models.statistic_query_input import StatisticQueryInput
from dhicn_wd_domain_service.models.stream import Stream
from dhicn_wd_domain_service.models.tank_storage_data import TankStorageData
from dhicn_wd_domain_service.models.ts_pairs import TsPairs
from dhicn_wd_domain_service.models.update_control_ts_input import UpdateControlTsInput
from dhicn_wd_domain_service.models.update_curve_ts_input import UpdateCurveTsInput
from dhicn_wd_domain_service.models.update_pattern_ts_input import UpdatePatternTsInput
from dhicn_wd_domain_service.models.update_pipe_risk_param_input import UpdatePipeRiskParamInput
from dhicn_wd_domain_service.models.update_pipe_risk_property_input import UpdatePipeRiskPropertyInput
from dhicn_wd_domain_service.models.update_pipe_risk_weight_input import UpdatePipeRiskWeightInput
from dhicn_wd_domain_service.models.value_info import ValueInfo
from dhicn_wd_domain_service.models.valve_info import ValveInfo
from dhicn_wd_domain_service.models.wd_component_detail_input import WdComponentDetailInput
from dhicn_wd_domain_service.models.wd_event_detail_input import WdEventDetailInput
from dhicn_wd_domain_service.models.wd_indicator_attr import WdIndicatorAttr
from dhicn_wd_domain_service.models.wq_event_detail_input import WqEventDetailInput

