# coding: utf-8

# flake8: noqa
"""
    message-center-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from dhicn_message_service.models.add_message_type_input import AddMessageTypeInput
from dhicn_message_service.models.add_msg_type_temp_local_input import AddMsgTypeTempLocalInput
from dhicn_message_service.models.add_user_msg import AddUserMsg
from dhicn_message_service.models.count_by_level import CountByLevel
from dhicn_message_service.models.delete_client_input import DeleteClientInput
from dhicn_message_service.models.get_lastest_message_input import GetLastestMessageInput
from dhicn_message_service.models.last_msg import LastMsg
from dhicn_message_service.models.lastest_message_by_msg_type_input import LastestMessageByMsgTypeInput
from dhicn_message_service.models.message_type_output import MessageTypeOutput
from dhicn_message_service.models.message_type_output_page import MessageTypeOutputPage
from dhicn_message_service.models.msg_template_obj import MsgTemplateObj
from dhicn_message_service.models.msg_type_temp_local_output import MsgTypeTempLocalOutput
from dhicn_message_service.models.msg_type_temp_local_output_page import MsgTypeTempLocalOutputPage
from dhicn_message_service.models.remote_service_error_info import RemoteServiceErrorInfo
from dhicn_message_service.models.remote_service_error_response import RemoteServiceErrorResponse
from dhicn_message_service.models.remote_service_validation_error_info import RemoteServiceValidationErrorInfo
from dhicn_message_service.models.save_client_input import SaveClientInput
from dhicn_message_service.models.unread_count_query_input import UnreadCountQueryInput
from dhicn_message_service.models.unread_count_query_output import UnreadCountQueryOutput
from dhicn_message_service.models.update_message_type_input import UpdateMessageTypeInput
from dhicn_message_service.models.update_msg_type_temp_local_input import UpdateMsgTypeTempLocalInput
from dhicn_message_service.models.update_user_msg_status import UpdateUserMsgStatus
from dhicn_message_service.models.user_message_object import UserMessageObject
from dhicn_message_service.models.user_msg_output import UserMsgOutput
from dhicn_message_service.models.user_msg_output_page import UserMsgOutputPage
