# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class BurstPipeValvesItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pipe_id': 'str',
        'gis_id': 'str',
        'x': 'float',
        'y': 'float'
    }

    attribute_map = {
        'pipe_id': 'pipeId',
        'gis_id': 'gisId',
        'x': 'x',
        'y': 'y'
    }

    def __init__(self, pipe_id=None, gis_id=None, x=None, y=None, local_vars_configuration=None):  # noqa: E501
        """BurstPipeValvesItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pipe_id = None
        self._gis_id = None
        self._x = None
        self._y = None
        self.discriminator = None

        self.pipe_id = pipe_id
        self.gis_id = gis_id
        if x is not None:
            self.x = x
        if y is not None:
            self.y = y

    @property
    def pipe_id(self):
        """Gets the pipe_id of this BurstPipeValvesItem.  # noqa: E501

        管段muid  # noqa: E501

        :return: The pipe_id of this BurstPipeValvesItem.  # noqa: E501
        :rtype: str
        """
        return self._pipe_id

    @pipe_id.setter
    def pipe_id(self, pipe_id):
        """Sets the pipe_id of this BurstPipeValvesItem.

        管段muid  # noqa: E501

        :param pipe_id: The pipe_id of this BurstPipeValvesItem.  # noqa: E501
        :type: str
        """

        self._pipe_id = pipe_id

    @property
    def gis_id(self):
        """Gets the gis_id of this BurstPipeValvesItem.  # noqa: E501

        爆管的位置  # noqa: E501

        :return: The gis_id of this BurstPipeValvesItem.  # noqa: E501
        :rtype: str
        """
        return self._gis_id

    @gis_id.setter
    def gis_id(self, gis_id):
        """Sets the gis_id of this BurstPipeValvesItem.

        爆管的位置  # noqa: E501

        :param gis_id: The gis_id of this BurstPipeValvesItem.  # noqa: E501
        :type: str
        """

        self._gis_id = gis_id

    @property
    def x(self):
        """Gets the x of this BurstPipeValvesItem.  # noqa: E501

        爆管的位置 - X  # noqa: E501

        :return: The x of this BurstPipeValvesItem.  # noqa: E501
        :rtype: float
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this BurstPipeValvesItem.

        爆管的位置 - X  # noqa: E501

        :param x: The x of this BurstPipeValvesItem.  # noqa: E501
        :type: float
        """

        self._x = x

    @property
    def y(self):
        """Gets the y of this BurstPipeValvesItem.  # noqa: E501

        爆管的位置 - Y  # noqa: E501

        :return: The y of this BurstPipeValvesItem.  # noqa: E501
        :rtype: float
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this BurstPipeValvesItem.

        爆管的位置 - Y  # noqa: E501

        :param y: The y of this BurstPipeValvesItem.  # noqa: E501
        :type: float
        """

        self._y = y

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BurstPipeValvesItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BurstPipeValvesItem):
            return True

        return self.to_dict() != other.to_dict()
