# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class IntelligentDeniConfigInOut(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'display_type': 'int',
        'display_type_name': 'str',
        'codes': 'str',
        'sub_type': 'str',
        'is_input_point': 'bool',
        'ext_info': 'str',
        'product_line': 'str',
        'category': 'int'
    }

    attribute_map = {
        'id': 'id',
        'display_type': 'displayType',
        'display_type_name': 'displayTypeName',
        'codes': 'codes',
        'sub_type': 'subType',
        'is_input_point': 'isInputPoint',
        'ext_info': 'extInfo',
        'product_line': 'productLine',
        'category': 'category'
    }

    def __init__(self, id=None, display_type=None, display_type_name=None, codes=None, sub_type=None, is_input_point=None, ext_info=None, product_line=None, category=None, local_vars_configuration=None):  # noqa: E501
        """IntelligentDeniConfigInOut - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._display_type = None
        self._display_type_name = None
        self._codes = None
        self._sub_type = None
        self._is_input_point = None
        self._ext_info = None
        self._product_line = None
        self._category = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if display_type is not None:
            self.display_type = display_type
        self.display_type_name = display_type_name
        self.codes = codes
        self.sub_type = sub_type
        if is_input_point is not None:
            self.is_input_point = is_input_point
        self.ext_info = ext_info
        self.product_line = product_line
        if category is not None:
            self.category = category

    @property
    def id(self):
        """Gets the id of this IntelligentDeniConfigInOut.  # noqa: E501

        配置ID config id  # noqa: E501

        :return: The id of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IntelligentDeniConfigInOut.

        配置ID config id  # noqa: E501

        :param id: The id of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def display_type(self):
        """Gets the display_type of this IntelligentDeniConfigInOut.  # noqa: E501

        展示类型枚举 display type  # noqa: E501

        :return: The display_type of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: int
        """
        return self._display_type

    @display_type.setter
    def display_type(self, display_type):
        """Sets the display_type of this IntelligentDeniConfigInOut.

        展示类型枚举 display type  # noqa: E501

        :param display_type: The display_type of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: int
        """

        self._display_type = display_type

    @property
    def display_type_name(self):
        """Gets the display_type_name of this IntelligentDeniConfigInOut.  # noqa: E501

        展示类型名称 display type name  # noqa: E501

        :return: The display_type_name of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._display_type_name

    @display_type_name.setter
    def display_type_name(self, display_type_name):
        """Sets the display_type_name of this IntelligentDeniConfigInOut.

        展示类型名称 display type name  # noqa: E501

        :param display_type_name: The display_type_name of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: str
        """

        self._display_type_name = display_type_name

    @property
    def codes(self):
        """Gets the codes of this IntelligentDeniConfigInOut.  # noqa: E501

        系统点位编码，逗号分割 system point codes, seperated by comma  # noqa: E501

        :return: The codes of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._codes

    @codes.setter
    def codes(self, codes):
        """Sets the codes of this IntelligentDeniConfigInOut.

        系统点位编码，逗号分割 system point codes, seperated by comma  # noqa: E501

        :param codes: The codes of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: str
        """

        self._codes = codes

    @property
    def sub_type(self):
        """Gets the sub_type of this IntelligentDeniConfigInOut.  # noqa: E501

        点位类型 point type  # noqa: E501

        :return: The sub_type of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._sub_type

    @sub_type.setter
    def sub_type(self, sub_type):
        """Sets the sub_type of this IntelligentDeniConfigInOut.

        点位类型 point type  # noqa: E501

        :param sub_type: The sub_type of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: str
        """

        self._sub_type = sub_type

    @property
    def is_input_point(self):
        """Gets the is_input_point of this IntelligentDeniConfigInOut.  # noqa: E501

        是否为输入点位 if it is an online point for input  # noqa: E501

        :return: The is_input_point of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: bool
        """
        return self._is_input_point

    @is_input_point.setter
    def is_input_point(self, is_input_point):
        """Sets the is_input_point of this IntelligentDeniConfigInOut.

        是否为输入点位 if it is an online point for input  # noqa: E501

        :param is_input_point: The is_input_point of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: bool
        """

        self._is_input_point = is_input_point

    @property
    def ext_info(self):
        """Gets the ext_info of this IntelligentDeniConfigInOut.  # noqa: E501

        扩展信息，生化池序号 extend information for biochemical pool index  # noqa: E501

        :return: The ext_info of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._ext_info

    @ext_info.setter
    def ext_info(self, ext_info):
        """Sets the ext_info of this IntelligentDeniConfigInOut.

        扩展信息，生化池序号 extend information for biochemical pool index  # noqa: E501

        :param ext_info: The ext_info of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: str
        """

        self._ext_info = ext_info

    @property
    def product_line(self):
        """Gets the product_line of this IntelligentDeniConfigInOut.  # noqa: E501

        生产线代码 product line code  # noqa: E501

        :return: The product_line of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._product_line

    @product_line.setter
    def product_line(self, product_line):
        """Sets the product_line of this IntelligentDeniConfigInOut.

        生产线代码 product line code  # noqa: E501

        :param product_line: The product_line of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: str
        """

        self._product_line = product_line

    @property
    def category(self):
        """Gets the category of this IntelligentDeniConfigInOut.  # noqa: E501

        药剂投加类别  # noqa: E501

        :return: The category of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: int
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this IntelligentDeniConfigInOut.

        药剂投加类别  # noqa: E501

        :param category: The category of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: int
        """
        allowed_values = [1, 2, 3, 4]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and category not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `category` ({0}), must be one of {1}"  # noqa: E501
                .format(category, allowed_values)
            )

        self._category = category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IntelligentDeniConfigInOut):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IntelligentDeniConfigInOut):
            return True

        return self.to_dict() != other.to_dict()
