# coding: utf-8

"""
    digital-twin-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_digital_twin_service.configuration import Configuration


class Coordinate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'x': 'float',
        'y': 'float',
        'z': 'float',
        'm': 'float',
        'coordinate_value': 'Coordinate',
        'is_valid': 'bool'
    }

    attribute_map = {
        'x': 'x',
        'y': 'y',
        'z': 'z',
        'm': 'm',
        'coordinate_value': 'coordinateValue',
        'is_valid': 'isValid'
    }

    def __init__(self, x=None, y=None, z=None, m=None, coordinate_value=None, is_valid=None, local_vars_configuration=None):  # noqa: E501
        """Coordinate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._x = None
        self._y = None
        self._z = None
        self._m = None
        self._coordinate_value = None
        self._is_valid = None
        self.discriminator = None

        if x is not None:
            self.x = x
        if y is not None:
            self.y = y
        if z is not None:
            self.z = z
        if m is not None:
            self.m = m
        if coordinate_value is not None:
            self.coordinate_value = coordinate_value
        if is_valid is not None:
            self.is_valid = is_valid

    @property
    def x(self):
        """Gets the x of this Coordinate.  # noqa: E501


        :return: The x of this Coordinate.  # noqa: E501
        :rtype: float
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this Coordinate.


        :param x: The x of this Coordinate.  # noqa: E501
        :type: float
        """

        self._x = x

    @property
    def y(self):
        """Gets the y of this Coordinate.  # noqa: E501


        :return: The y of this Coordinate.  # noqa: E501
        :rtype: float
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this Coordinate.


        :param y: The y of this Coordinate.  # noqa: E501
        :type: float
        """

        self._y = y

    @property
    def z(self):
        """Gets the z of this Coordinate.  # noqa: E501


        :return: The z of this Coordinate.  # noqa: E501
        :rtype: float
        """
        return self._z

    @z.setter
    def z(self, z):
        """Sets the z of this Coordinate.


        :param z: The z of this Coordinate.  # noqa: E501
        :type: float
        """

        self._z = z

    @property
    def m(self):
        """Gets the m of this Coordinate.  # noqa: E501


        :return: The m of this Coordinate.  # noqa: E501
        :rtype: float
        """
        return self._m

    @m.setter
    def m(self, m):
        """Sets the m of this Coordinate.


        :param m: The m of this Coordinate.  # noqa: E501
        :type: float
        """

        self._m = m

    @property
    def coordinate_value(self):
        """Gets the coordinate_value of this Coordinate.  # noqa: E501


        :return: The coordinate_value of this Coordinate.  # noqa: E501
        :rtype: Coordinate
        """
        return self._coordinate_value

    @coordinate_value.setter
    def coordinate_value(self, coordinate_value):
        """Sets the coordinate_value of this Coordinate.


        :param coordinate_value: The coordinate_value of this Coordinate.  # noqa: E501
        :type: Coordinate
        """

        self._coordinate_value = coordinate_value

    @property
    def is_valid(self):
        """Gets the is_valid of this Coordinate.  # noqa: E501


        :return: The is_valid of this Coordinate.  # noqa: E501
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """Sets the is_valid of this Coordinate.


        :param is_valid: The is_valid of this Coordinate.  # noqa: E501
        :type: bool
        """

        self._is_valid = is_valid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Coordinate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Coordinate):
            return True

        return self.to_dict() != other.to_dict()
