# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class ModelResultRiverWqInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'scenario_id': 'str',
        'wq_item': 'str',
        'frequency': 'int',
        'start_time': 'datetime',
        'end_time': 'datetime'
    }

    attribute_map = {
        'scenario_id': 'scenarioId',
        'wq_item': 'wqItem',
        'frequency': 'frequency',
        'start_time': 'startTime',
        'end_time': 'endTime'
    }

    def __init__(self, scenario_id=None, wq_item=None, frequency=None, start_time=None, end_time=None, local_vars_configuration=None):  # noqa: E501
        """ModelResultRiverWqInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._scenario_id = None
        self._wq_item = None
        self._frequency = None
        self._start_time = None
        self._end_time = None
        self.discriminator = None

        self.scenario_id = scenario_id
        self.wq_item = wq_item
        if frequency is not None:
            self.frequency = frequency
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time

    @property
    def scenario_id(self):
        """Gets the scenario_id of this ModelResultRiverWqInput.  # noqa: E501

        方案id scenario id  # noqa: E501

        :return: The scenario_id of this ModelResultRiverWqInput.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this ModelResultRiverWqInput.

        方案id scenario id  # noqa: E501

        :param scenario_id: The scenario_id of this ModelResultRiverWqInput.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def wq_item(self):
        """Gets the wq_item of this ModelResultRiverWqInput.  # noqa: E501

        水质 water quality  # noqa: E501

        :return: The wq_item of this ModelResultRiverWqInput.  # noqa: E501
        :rtype: str
        """
        return self._wq_item

    @wq_item.setter
    def wq_item(self, wq_item):
        """Sets the wq_item of this ModelResultRiverWqInput.

        水质 water quality  # noqa: E501

        :param wq_item: The wq_item of this ModelResultRiverWqInput.  # noqa: E501
        :type: str
        """

        self._wq_item = wq_item

    @property
    def frequency(self):
        """Gets the frequency of this ModelResultRiverWqInput.  # noqa: E501

        频率 frequency  # noqa: E501

        :return: The frequency of this ModelResultRiverWqInput.  # noqa: E501
        :rtype: int
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        """Sets the frequency of this ModelResultRiverWqInput.

        频率 frequency  # noqa: E501

        :param frequency: The frequency of this ModelResultRiverWqInput.  # noqa: E501
        :type: int
        """

        self._frequency = frequency

    @property
    def start_time(self):
        """Gets the start_time of this ModelResultRiverWqInput.  # noqa: E501

        开始时间 start time  # noqa: E501

        :return: The start_time of this ModelResultRiverWqInput.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this ModelResultRiverWqInput.

        开始时间 start time  # noqa: E501

        :param start_time: The start_time of this ModelResultRiverWqInput.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this ModelResultRiverWqInput.  # noqa: E501

        结束时间 end time  # noqa: E501

        :return: The end_time of this ModelResultRiverWqInput.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this ModelResultRiverWqInput.

        结束时间 end time  # noqa: E501

        :param end_time: The end_time of this ModelResultRiverWqInput.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelResultRiverWqInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelResultRiverWqInput):
            return True

        return self.to_dict() != other.to_dict()
