# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class DeviceDetailInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'label': 'str',
        'description': 'str',
        'group': 'str',
        'location': 'str',
        'type': 'str',
        'device_indicators': 'list[DeviceIndicatorInfo]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'label': 'label',
        'description': 'description',
        'group': 'group',
        'location': 'location',
        'type': 'type',
        'device_indicators': 'deviceIndicators'
    }

    def __init__(self, id=None, name=None, label=None, description=None, group=None, location=None, type=None, device_indicators=None, local_vars_configuration=None):  # noqa: E501
        """DeviceDetailInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._label = None
        self._description = None
        self._group = None
        self._location = None
        self._type = None
        self._device_indicators = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        self.label = label
        self.description = description
        self.group = group
        self.location = location
        self.type = type
        self.device_indicators = device_indicators

    @property
    def id(self):
        """Gets the id of this DeviceDetailInfo.  # noqa: E501

        设备id  # noqa: E501

        :return: The id of this DeviceDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeviceDetailInfo.

        设备id  # noqa: E501

        :param id: The id of this DeviceDetailInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this DeviceDetailInfo.  # noqa: E501

        设备名  # noqa: E501

        :return: The name of this DeviceDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DeviceDetailInfo.

        设备名  # noqa: E501

        :param name: The name of this DeviceDetailInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def label(self):
        """Gets the label of this DeviceDetailInfo.  # noqa: E501


        :return: The label of this DeviceDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this DeviceDetailInfo.


        :param label: The label of this DeviceDetailInfo.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def description(self):
        """Gets the description of this DeviceDetailInfo.  # noqa: E501


        :return: The description of this DeviceDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DeviceDetailInfo.


        :param description: The description of this DeviceDetailInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def group(self):
        """Gets the group of this DeviceDetailInfo.  # noqa: E501

        设备分组  # noqa: E501

        :return: The group of this DeviceDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this DeviceDetailInfo.

        设备分组  # noqa: E501

        :param group: The group of this DeviceDetailInfo.  # noqa: E501
        :type: str
        """

        self._group = group

    @property
    def location(self):
        """Gets the location of this DeviceDetailInfo.  # noqa: E501

        位置  # noqa: E501

        :return: The location of this DeviceDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this DeviceDetailInfo.

        位置  # noqa: E501

        :param location: The location of this DeviceDetailInfo.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def type(self):
        """Gets the type of this DeviceDetailInfo.  # noqa: E501

        设备类型  # noqa: E501

        :return: The type of this DeviceDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DeviceDetailInfo.

        设备类型  # noqa: E501

        :param type: The type of this DeviceDetailInfo.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def device_indicators(self):
        """Gets the device_indicators of this DeviceDetailInfo.  # noqa: E501

        设备指标列表  # noqa: E501

        :return: The device_indicators of this DeviceDetailInfo.  # noqa: E501
        :rtype: list[DeviceIndicatorInfo]
        """
        return self._device_indicators

    @device_indicators.setter
    def device_indicators(self, device_indicators):
        """Sets the device_indicators of this DeviceDetailInfo.

        设备指标列表  # noqa: E501

        :param device_indicators: The device_indicators of this DeviceDetailInfo.  # noqa: E501
        :type: list[DeviceIndicatorInfo]
        """

        self._device_indicators = device_indicators

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceDetailInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeviceDetailInfo):
            return True

        return self.to_dict() != other.to_dict()
