# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class ExecutePlcInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'execute_time': 'datetime',
        'dosing_param_setting_dtos': 'list[DosingParamSettingDto]'
    }

    attribute_map = {
        'execute_time': 'executeTime',
        'dosing_param_setting_dtos': 'dosingParamSettingDtos'
    }

    def __init__(self, execute_time=None, dosing_param_setting_dtos=None, local_vars_configuration=None):  # noqa: E501
        """ExecutePlcInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._execute_time = None
        self._dosing_param_setting_dtos = None
        self.discriminator = None

        if execute_time is not None:
            self.execute_time = execute_time
        self.dosing_param_setting_dtos = dosing_param_setting_dtos

    @property
    def execute_time(self):
        """Gets the execute_time of this ExecutePlcInput.  # noqa: E501

        执行PLC时间  # noqa: E501

        :return: The execute_time of this ExecutePlcInput.  # noqa: E501
        :rtype: datetime
        """
        return self._execute_time

    @execute_time.setter
    def execute_time(self, execute_time):
        """Sets the execute_time of this ExecutePlcInput.

        执行PLC时间  # noqa: E501

        :param execute_time: The execute_time of this ExecutePlcInput.  # noqa: E501
        :type: datetime
        """

        self._execute_time = execute_time

    @property
    def dosing_param_setting_dtos(self):
        """Gets the dosing_param_setting_dtos of this ExecutePlcInput.  # noqa: E501

        加药参数  # noqa: E501

        :return: The dosing_param_setting_dtos of this ExecutePlcInput.  # noqa: E501
        :rtype: list[DosingParamSettingDto]
        """
        return self._dosing_param_setting_dtos

    @dosing_param_setting_dtos.setter
    def dosing_param_setting_dtos(self, dosing_param_setting_dtos):
        """Sets the dosing_param_setting_dtos of this ExecutePlcInput.

        加药参数  # noqa: E501

        :param dosing_param_setting_dtos: The dosing_param_setting_dtos of this ExecutePlcInput.  # noqa: E501
        :type: list[DosingParamSettingDto]
        """

        self._dosing_param_setting_dtos = dosing_param_setting_dtos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExecutePlcInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExecutePlcInput):
            return True

        return self.to_dict() != other.to_dict()
