# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class UpdateAssetInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'type': 'str',
        'label': 'str',
        'description': 'str',
        'attributes': 'list[StringStringKeyValue]',
        'id': 'str',
        'created_time': 'int'
    }

    attribute_map = {
        'name': 'name',
        'type': 'type',
        'label': 'label',
        'description': 'description',
        'attributes': 'attributes',
        'id': 'id',
        'created_time': 'createdTime'
    }

    def __init__(self, name=None, type=None, label=None, description=None, attributes=None, id=None, created_time=None, local_vars_configuration=None):  # noqa: E501
        """UpdateAssetInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._type = None
        self._label = None
        self._description = None
        self._attributes = None
        self._id = None
        self._created_time = None
        self.discriminator = None

        self.name = name
        self.type = type
        self.label = label
        self.description = description
        self.attributes = attributes
        self.id = id
        if created_time is not None:
            self.created_time = created_time

    @property
    def name(self):
        """Gets the name of this UpdateAssetInput.  # noqa: E501

        资产名称 asset name  # noqa: E501

        :return: The name of this UpdateAssetInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateAssetInput.

        资产名称 asset name  # noqa: E501

        :param name: The name of this UpdateAssetInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def type(self):
        """Gets the type of this UpdateAssetInput.  # noqa: E501

        资产类型（自定义） asset type (customized)  # noqa: E501

        :return: The type of this UpdateAssetInput.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this UpdateAssetInput.

        资产类型（自定义） asset type (customized)  # noqa: E501

        :param type: The type of this UpdateAssetInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def label(self):
        """Gets the label of this UpdateAssetInput.  # noqa: E501

        资产标签 asset label  # noqa: E501

        :return: The label of this UpdateAssetInput.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this UpdateAssetInput.

        资产标签 asset label  # noqa: E501

        :param label: The label of this UpdateAssetInput.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def description(self):
        """Gets the description of this UpdateAssetInput.  # noqa: E501

        资产描述 asset description  # noqa: E501

        :return: The description of this UpdateAssetInput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdateAssetInput.

        资产描述 asset description  # noqa: E501

        :param description: The description of this UpdateAssetInput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def attributes(self):
        """Gets the attributes of this UpdateAssetInput.  # noqa: E501

        资产自定义属性 asset customized attributes  # noqa: E501

        :return: The attributes of this UpdateAssetInput.  # noqa: E501
        :rtype: list[StringStringKeyValue]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this UpdateAssetInput.

        资产自定义属性 asset customized attributes  # noqa: E501

        :param attributes: The attributes of this UpdateAssetInput.  # noqa: E501
        :type: list[StringStringKeyValue]
        """

        self._attributes = attributes

    @property
    def id(self):
        """Gets the id of this UpdateAssetInput.  # noqa: E501

        资产Id asset Id  # noqa: E501

        :return: The id of this UpdateAssetInput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UpdateAssetInput.

        资产Id asset Id  # noqa: E501

        :param id: The id of this UpdateAssetInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this UpdateAssetInput.  # noqa: E501

        创建时间 asset createtion time  # noqa: E501

        :return: The created_time of this UpdateAssetInput.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this UpdateAssetInput.

        创建时间 asset createtion time  # noqa: E501

        :param created_time: The created_time of this UpdateAssetInput.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAssetInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateAssetInput):
            return True

        return self.to_dict() != other.to_dict()
