# coding: utf-8

"""
    digital-twin-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_digital_twin_service.configuration import Configuration


class ModelBoundaryConfigInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'model_point_id': 'str',
        'show_name': 'str',
        'dfs0_file': 'str',
        'data_item': 'str',
        'point_json': 'list[BoundaryConfigPointItem]',
        'measure_expression': 'PointExpressItem',
        'forecast_expression': 'PointExpressItem',
        'template_id': 'str',
        'boundary_id': 'str',
        'boundary_type': 'int',
        'data_type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'model_point_id': 'modelPointId',
        'show_name': 'showName',
        'dfs0_file': 'dfs0File',
        'data_item': 'dataItem',
        'point_json': 'pointJson',
        'measure_expression': 'measureExpression',
        'forecast_expression': 'forecastExpression',
        'template_id': 'templateId',
        'boundary_id': 'boundaryId',
        'boundary_type': 'boundaryType',
        'data_type': 'dataType'
    }

    def __init__(self, id=None, model_point_id=None, show_name=None, dfs0_file=None, data_item=None, point_json=None, measure_expression=None, forecast_expression=None, template_id=None, boundary_id=None, boundary_type=None, data_type=None, local_vars_configuration=None):  # noqa: E501
        """ModelBoundaryConfigInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._model_point_id = None
        self._show_name = None
        self._dfs0_file = None
        self._data_item = None
        self._point_json = None
        self._measure_expression = None
        self._forecast_expression = None
        self._template_id = None
        self._boundary_id = None
        self._boundary_type = None
        self._data_type = None
        self.discriminator = None

        self.id = id
        if model_point_id is not None:
            self.model_point_id = model_point_id
        self.show_name = show_name
        self.dfs0_file = dfs0_file
        self.data_item = data_item
        self.point_json = point_json
        if measure_expression is not None:
            self.measure_expression = measure_expression
        if forecast_expression is not None:
            self.forecast_expression = forecast_expression
        if template_id is not None:
            self.template_id = template_id
        self.boundary_id = boundary_id
        if boundary_type is not None:
            self.boundary_type = boundary_type
        self.data_type = data_type

    @property
    def id(self):
        """Gets the id of this ModelBoundaryConfigInput.  # noqa: E501

        配置项ID configuration id  # noqa: E501

        :return: The id of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ModelBoundaryConfigInput.

        配置项ID configuration id  # noqa: E501

        :param id: The id of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def model_point_id(self):
        """Gets the model_point_id of this ModelBoundaryConfigInput.  # noqa: E501

        模型点位ID model point id  # noqa: E501

        :return: The model_point_id of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._model_point_id

    @model_point_id.setter
    def model_point_id(self, model_point_id):
        """Sets the model_point_id of this ModelBoundaryConfigInput.

        模型点位ID model point id  # noqa: E501

        :param model_point_id: The model_point_id of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._model_point_id = model_point_id

    @property
    def show_name(self):
        """Gets the show_name of this ModelBoundaryConfigInput.  # noqa: E501

        边界显示名称 boundary show name  # noqa: E501

        :return: The show_name of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._show_name

    @show_name.setter
    def show_name(self, show_name):
        """Sets the show_name of this ModelBoundaryConfigInput.

        边界显示名称 boundary show name  # noqa: E501

        :param show_name: The show_name of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._show_name = show_name

    @property
    def dfs0_file(self):
        """Gets the dfs0_file of this ModelBoundaryConfigInput.  # noqa: E501

        边界时间序列数据dfs0文件的相对路径 Dfs0 file path  # noqa: E501

        :return: The dfs0_file of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._dfs0_file

    @dfs0_file.setter
    def dfs0_file(self, dfs0_file):
        """Sets the dfs0_file of this ModelBoundaryConfigInput.

        边界时间序列数据dfs0文件的相对路径 Dfs0 file path  # noqa: E501

        :param dfs0_file: The dfs0_file of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._dfs0_file = dfs0_file

    @property
    def data_item(self):
        """Gets the data_item of this ModelBoundaryConfigInput.  # noqa: E501

        边界时间序列数据Dfs0文件中的数据项名称 Dfs0 data item  # noqa: E501

        :return: The data_item of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._data_item

    @data_item.setter
    def data_item(self, data_item):
        """Sets the data_item of this ModelBoundaryConfigInput.

        边界时间序列数据Dfs0文件中的数据项名称 Dfs0 data item  # noqa: E501

        :param data_item: The data_item of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._data_item = data_item

    @property
    def point_json(self):
        """Gets the point_json of this ModelBoundaryConfigInput.  # noqa: E501

        对应的设备指标信息 corresponding device indicators  # noqa: E501

        :return: The point_json of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: list[BoundaryConfigPointItem]
        """
        return self._point_json

    @point_json.setter
    def point_json(self, point_json):
        """Sets the point_json of this ModelBoundaryConfigInput.

        对应的设备指标信息 corresponding device indicators  # noqa: E501

        :param point_json: The point_json of this ModelBoundaryConfigInput.  # noqa: E501
        :type: list[BoundaryConfigPointItem]
        """

        self._point_json = point_json

    @property
    def measure_expression(self):
        """Gets the measure_expression of this ModelBoundaryConfigInput.  # noqa: E501


        :return: The measure_expression of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: PointExpressItem
        """
        return self._measure_expression

    @measure_expression.setter
    def measure_expression(self, measure_expression):
        """Sets the measure_expression of this ModelBoundaryConfigInput.


        :param measure_expression: The measure_expression of this ModelBoundaryConfigInput.  # noqa: E501
        :type: PointExpressItem
        """

        self._measure_expression = measure_expression

    @property
    def forecast_expression(self):
        """Gets the forecast_expression of this ModelBoundaryConfigInput.  # noqa: E501


        :return: The forecast_expression of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: PointExpressItem
        """
        return self._forecast_expression

    @forecast_expression.setter
    def forecast_expression(self, forecast_expression):
        """Sets the forecast_expression of this ModelBoundaryConfigInput.


        :param forecast_expression: The forecast_expression of this ModelBoundaryConfigInput.  # noqa: E501
        :type: PointExpressItem
        """

        self._forecast_expression = forecast_expression

    @property
    def template_id(self):
        """Gets the template_id of this ModelBoundaryConfigInput.  # noqa: E501

        模板方案Id template scenario id  # noqa: E501

        :return: The template_id of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this ModelBoundaryConfigInput.

        模板方案Id template scenario id  # noqa: E501

        :param template_id: The template_id of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._template_id = template_id

    @property
    def boundary_id(self):
        """Gets the boundary_id of this ModelBoundaryConfigInput.  # noqa: E501

        模型边界ID boundary id  # noqa: E501

        :return: The boundary_id of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._boundary_id

    @boundary_id.setter
    def boundary_id(self, boundary_id):
        """Sets the boundary_id of this ModelBoundaryConfigInput.

        模型边界ID boundary id  # noqa: E501

        :param boundary_id: The boundary_id of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._boundary_id = boundary_id

    @property
    def boundary_type(self):
        """Gets the boundary_type of this ModelBoundaryConfigInput.  # noqa: E501

        1-Rainfall 2-Air_Temperature 3-Evapo_Transpiration 4-Catchment_discharge 5-Catchment_discharge_per_area 6-Catchment_discharge_per_PE 7-Load_point_discharge 8-Load_point_discharge_per_unit 9-Inflow_to_Node 10-Inflow_to_Link 11-Inflow_from_Result_File 12-Outlet_Water_Level 13-Exfiltration_from_node 14-Exfiltration_from_link 15-StormWater_load_surface 16-StormWater_load_RDII 17-Open_Inflow_To_River 18-Source_Inflow_To_River 19-River_Water_Level 20-River_QH_Relation 21-Free_River_Outflow 22-Closed_River_Boundary 30-CS_Pump 31-CS_Valve 32-River_Pump 33-River_Gate 41-Pollutant_concentration 42-Pollutant_load 43-Sediment_concentration 44-Sediment_load 45-Microorganisms 46-Temperature 47-Salinity 48-PH 49-Wate_Age 50-Wate_Blend 51-WD_Pattern 52-WD_Curve 53-WD_Pump 54-WD_Valve 999-Other -1-Undefined   # noqa: E501

        :return: The boundary_type of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: int
        """
        return self._boundary_type

    @boundary_type.setter
    def boundary_type(self, boundary_type):
        """Sets the boundary_type of this ModelBoundaryConfigInput.

        1-Rainfall 2-Air_Temperature 3-Evapo_Transpiration 4-Catchment_discharge 5-Catchment_discharge_per_area 6-Catchment_discharge_per_PE 7-Load_point_discharge 8-Load_point_discharge_per_unit 9-Inflow_to_Node 10-Inflow_to_Link 11-Inflow_from_Result_File 12-Outlet_Water_Level 13-Exfiltration_from_node 14-Exfiltration_from_link 15-StormWater_load_surface 16-StormWater_load_RDII 17-Open_Inflow_To_River 18-Source_Inflow_To_River 19-River_Water_Level 20-River_QH_Relation 21-Free_River_Outflow 22-Closed_River_Boundary 30-CS_Pump 31-CS_Valve 32-River_Pump 33-River_Gate 41-Pollutant_concentration 42-Pollutant_load 43-Sediment_concentration 44-Sediment_load 45-Microorganisms 46-Temperature 47-Salinity 48-PH 49-Wate_Age 50-Wate_Blend 51-WD_Pattern 52-WD_Curve 53-WD_Pump 54-WD_Valve 999-Other -1-Undefined   # noqa: E501

        :param boundary_type: The boundary_type of this ModelBoundaryConfigInput.  # noqa: E501
        :type: int
        """
        allowed_values = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 30, 31, 32, 33, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 999, -1]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and boundary_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `boundary_type` ({0}), must be one of {1}"  # noqa: E501
                .format(boundary_type, allowed_values)
            )

        self._boundary_type = boundary_type

    @property
    def data_type(self):
        """Gets the data_type of this ModelBoundaryConfigInput.  # noqa: E501

        数据类型（主要针对结构物） data type, mainly for structures  # noqa: E501

        :return: The data_type of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this ModelBoundaryConfigInput.

        数据类型（主要针对结构物） data type, mainly for structures  # noqa: E501

        :param data_type: The data_type of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelBoundaryConfigInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelBoundaryConfigInput):
            return True

        return self.to_dict() != other.to_dict()
