# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class OpcUaComAssemblyInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'device_name': 'str',
        'indicator': 'str',
        'indicator_id': 'str',
        'node_name': 'str',
        'node': 'str',
        'unit': 'str',
        'data_type': 'str',
        'decimal_places': 'int',
        'time_processing_mode': 'int',
        'is_open_sync': 'bool',
        'period': 'int',
        'opc_flag': 'str',
        'syn_freq': 'str'
    }

    attribute_map = {
        'id': 'id',
        'device_name': 'deviceName',
        'indicator': 'indicator',
        'indicator_id': 'indicatorId',
        'node_name': 'nodeName',
        'node': 'node',
        'unit': 'unit',
        'data_type': 'dataType',
        'decimal_places': 'decimalPlaces',
        'time_processing_mode': 'timeProcessingMode',
        'is_open_sync': 'isOpenSync',
        'period': 'period',
        'opc_flag': 'opcFlag',
        'syn_freq': 'synFreq'
    }

    def __init__(self, id=None, device_name=None, indicator=None, indicator_id=None, node_name=None, node=None, unit=None, data_type=None, decimal_places=None, time_processing_mode=None, is_open_sync=None, period=None, opc_flag=None, syn_freq=None, local_vars_configuration=None):  # noqa: E501
        """OpcUaComAssemblyInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._device_name = None
        self._indicator = None
        self._indicator_id = None
        self._node_name = None
        self._node = None
        self._unit = None
        self._data_type = None
        self._decimal_places = None
        self._time_processing_mode = None
        self._is_open_sync = None
        self._period = None
        self._opc_flag = None
        self._syn_freq = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.device_name = device_name
        self.indicator = indicator
        if indicator_id is not None:
            self.indicator_id = indicator_id
        self.node_name = node_name
        self.node = node
        self.unit = unit
        self.data_type = data_type
        if decimal_places is not None:
            self.decimal_places = decimal_places
        self.time_processing_mode = time_processing_mode
        self.is_open_sync = is_open_sync
        self.period = period
        self.opc_flag = opc_flag
        self.syn_freq = syn_freq

    @property
    def id(self):
        """Gets the id of this OpcUaComAssemblyInfo.  # noqa: E501

        Id Id  # noqa: E501

        :return: The id of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OpcUaComAssemblyInfo.

        Id Id  # noqa: E501

        :param id: The id of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def device_name(self):
        """Gets the device_name of this OpcUaComAssemblyInfo.  # noqa: E501

        设备名称  # noqa: E501

        :return: The device_name of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._device_name

    @device_name.setter
    def device_name(self, device_name):
        """Sets the device_name of this OpcUaComAssemblyInfo.

        设备名称  # noqa: E501

        :param device_name: The device_name of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._device_name = device_name

    @property
    def indicator(self):
        """Gets the indicator of this OpcUaComAssemblyInfo.  # noqa: E501

        指标  # noqa: E501

        :return: The indicator of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this OpcUaComAssemblyInfo.

        指标  # noqa: E501

        :param indicator: The indicator of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._indicator = indicator

    @property
    def indicator_id(self):
        """Gets the indicator_id of this OpcUaComAssemblyInfo.  # noqa: E501

        设备指标Id，对应着设备-指标 device indicator id  # noqa: E501

        :return: The indicator_id of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._indicator_id

    @indicator_id.setter
    def indicator_id(self, indicator_id):
        """Sets the indicator_id of this OpcUaComAssemblyInfo.

        设备指标Id，对应着设备-指标 device indicator id  # noqa: E501

        :param indicator_id: The indicator_id of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._indicator_id = indicator_id

    @property
    def node_name(self):
        """Gets the node_name of this OpcUaComAssemblyInfo.  # noqa: E501

        节点名称，如:主线静压式液位 node name  # noqa: E501

        :return: The node_name of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._node_name

    @node_name.setter
    def node_name(self, node_name):
        """Sets the node_name of this OpcUaComAssemblyInfo.

        节点名称，如:主线静压式液位 node name  # noqa: E501

        :param node_name: The node_name of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._node_name = node_name

    @property
    def node(self):
        """Gets the node of this OpcUaComAssemblyInfo.  # noqa: E501

        节点检测项 node detection item  # noqa: E501

        :return: The node of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._node

    @node.setter
    def node(self, node):
        """Sets the node of this OpcUaComAssemblyInfo.

        节点检测项 node detection item  # noqa: E501

        :param node: The node of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._node = node

    @property
    def unit(self):
        """Gets the unit of this OpcUaComAssemblyInfo.  # noqa: E501

        单位 unit  # noqa: E501

        :return: The unit of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this OpcUaComAssemblyInfo.

        单位 unit  # noqa: E501

        :param unit: The unit of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def data_type(self):
        """Gets the data_type of this OpcUaComAssemblyInfo.  # noqa: E501

        数据类型,BoolValue/DateTimeValue/DblValue/LongValue/StrValue data type: BoolValue/DateTimeValue/DblValue/LongValue/StrValue  # noqa: E501

        :return: The data_type of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this OpcUaComAssemblyInfo.

        数据类型,BoolValue/DateTimeValue/DblValue/LongValue/StrValue data type: BoolValue/DateTimeValue/DblValue/LongValue/StrValue  # noqa: E501

        :param data_type: The data_type of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    @property
    def decimal_places(self):
        """Gets the decimal_places of this OpcUaComAssemblyInfo.  # noqa: E501

        小数点数 decimal places  # noqa: E501

        :return: The decimal_places of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: int
        """
        return self._decimal_places

    @decimal_places.setter
    def decimal_places(self, decimal_places):
        """Sets the decimal_places of this OpcUaComAssemblyInfo.

        小数点数 decimal places  # noqa: E501

        :param decimal_places: The decimal_places of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: int
        """

        self._decimal_places = decimal_places

    @property
    def time_processing_mode(self):
        """Gets the time_processing_mode of this OpcUaComAssemblyInfo.  # noqa: E501

        时间处理模式,枚举：second秒、minute分、hour小时、original(默认原始值,不做处理)  # noqa: E501

        :return: The time_processing_mode of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: int
        """
        return self._time_processing_mode

    @time_processing_mode.setter
    def time_processing_mode(self, time_processing_mode):
        """Sets the time_processing_mode of this OpcUaComAssemblyInfo.

        时间处理模式,枚举：second秒、minute分、hour小时、original(默认原始值,不做处理)  # noqa: E501

        :param time_processing_mode: The time_processing_mode of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: int
        """
        allowed_values = [None,0, 1, 2, 3]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and time_processing_mode not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `time_processing_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(time_processing_mode, allowed_values)
            )

        self._time_processing_mode = time_processing_mode

    @property
    def is_open_sync(self):
        """Gets the is_open_sync of this OpcUaComAssemblyInfo.  # noqa: E501

        是否启用同步 Is open sync,  # noqa: E501

        :return: The is_open_sync of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_open_sync

    @is_open_sync.setter
    def is_open_sync(self, is_open_sync):
        """Sets the is_open_sync of this OpcUaComAssemblyInfo.

        是否启用同步 Is open sync,  # noqa: E501

        :param is_open_sync: The is_open_sync of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: bool
        """

        self._is_open_sync = is_open_sync

    @property
    def period(self):
        """Gets the period of this OpcUaComAssemblyInfo.  # noqa: E501

        时间步长  # noqa: E501

        :return: The period of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this OpcUaComAssemblyInfo.

        时间步长  # noqa: E501

        :param period: The period of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def opc_flag(self):
        """Gets the opc_flag of this OpcUaComAssemblyInfo.  # noqa: E501

        标识，OpcUaConfig表的OpcFlag  # noqa: E501

        :return: The opc_flag of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._opc_flag

    @opc_flag.setter
    def opc_flag(self, opc_flag):
        """Sets the opc_flag of this OpcUaComAssemblyInfo.

        标识，OpcUaConfig表的OpcFlag  # noqa: E501

        :param opc_flag: The opc_flag of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._opc_flag = opc_flag

    @property
    def syn_freq(self):
        """Gets the syn_freq of this OpcUaComAssemblyInfo.  # noqa: E501

        同步频率，例如：30s/5m/1h  # noqa: E501

        :return: The syn_freq of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._syn_freq

    @syn_freq.setter
    def syn_freq(self, syn_freq):
        """Sets the syn_freq of this OpcUaComAssemblyInfo.

        同步频率，例如：30s/5m/1h  # noqa: E501

        :param syn_freq: The syn_freq of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._syn_freq = syn_freq

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OpcUaComAssemblyInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OpcUaComAssemblyInfo):
            return True

        return self.to_dict() != other.to_dict()
