# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class FactoryConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'qmax': 'float',
        'qmin': 'float',
        'rate_of_change_sum_range_set_value1': 'float',
        'rate_of_change_sum_range_set_value2': 'float',
        'rate_of_change_sum_range_set_value3': 'float',
        'rate_of_change_sum_range_set_value4': 'float',
        'pump_station_feedback_increase_value1': 'float',
        'pump_station_feedback_increase_value2': 'float',
        'pump_station_feedback_increase_value3': 'float',
        'pump_station_feedback_increase_value4': 'float',
        'pump_station_feedback_increase_value5': 'float',
        'flow_change_value': 'float'
    }

    attribute_map = {
        'qmax': 'qmax',
        'qmin': 'qmin',
        'rate_of_change_sum_range_set_value1': 'rateOfChangeSumRangeSetValue1',
        'rate_of_change_sum_range_set_value2': 'rateOfChangeSumRangeSetValue2',
        'rate_of_change_sum_range_set_value3': 'rateOfChangeSumRangeSetValue3',
        'rate_of_change_sum_range_set_value4': 'rateOfChangeSumRangeSetValue4',
        'pump_station_feedback_increase_value1': 'pumpStationFeedbackIncreaseValue1',
        'pump_station_feedback_increase_value2': 'pumpStationFeedbackIncreaseValue2',
        'pump_station_feedback_increase_value3': 'pumpStationFeedbackIncreaseValue3',
        'pump_station_feedback_increase_value4': 'pumpStationFeedbackIncreaseValue4',
        'pump_station_feedback_increase_value5': 'pumpStationFeedbackIncreaseValue5',
        'flow_change_value': 'flowChangeValue'
    }

    def __init__(self, qmax=None, qmin=None, rate_of_change_sum_range_set_value1=None, rate_of_change_sum_range_set_value2=None, rate_of_change_sum_range_set_value3=None, rate_of_change_sum_range_set_value4=None, pump_station_feedback_increase_value1=None, pump_station_feedback_increase_value2=None, pump_station_feedback_increase_value3=None, pump_station_feedback_increase_value4=None, pump_station_feedback_increase_value5=None, flow_change_value=None, local_vars_configuration=None):  # noqa: E501
        """FactoryConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._qmax = None
        self._qmin = None
        self._rate_of_change_sum_range_set_value1 = None
        self._rate_of_change_sum_range_set_value2 = None
        self._rate_of_change_sum_range_set_value3 = None
        self._rate_of_change_sum_range_set_value4 = None
        self._pump_station_feedback_increase_value1 = None
        self._pump_station_feedback_increase_value2 = None
        self._pump_station_feedback_increase_value3 = None
        self._pump_station_feedback_increase_value4 = None
        self._pump_station_feedback_increase_value5 = None
        self._flow_change_value = None
        self.discriminator = None

        if qmax is not None:
            self.qmax = qmax
        if qmin is not None:
            self.qmin = qmin
        if rate_of_change_sum_range_set_value1 is not None:
            self.rate_of_change_sum_range_set_value1 = rate_of_change_sum_range_set_value1
        if rate_of_change_sum_range_set_value2 is not None:
            self.rate_of_change_sum_range_set_value2 = rate_of_change_sum_range_set_value2
        if rate_of_change_sum_range_set_value3 is not None:
            self.rate_of_change_sum_range_set_value3 = rate_of_change_sum_range_set_value3
        if rate_of_change_sum_range_set_value4 is not None:
            self.rate_of_change_sum_range_set_value4 = rate_of_change_sum_range_set_value4
        if pump_station_feedback_increase_value1 is not None:
            self.pump_station_feedback_increase_value1 = pump_station_feedback_increase_value1
        if pump_station_feedback_increase_value2 is not None:
            self.pump_station_feedback_increase_value2 = pump_station_feedback_increase_value2
        if pump_station_feedback_increase_value3 is not None:
            self.pump_station_feedback_increase_value3 = pump_station_feedback_increase_value3
        if pump_station_feedback_increase_value4 is not None:
            self.pump_station_feedback_increase_value4 = pump_station_feedback_increase_value4
        if pump_station_feedback_increase_value5 is not None:
            self.pump_station_feedback_increase_value5 = pump_station_feedback_increase_value5
        if flow_change_value is not None:
            self.flow_change_value = flow_change_value

    @property
    def qmax(self):
        """Gets the qmax of this FactoryConfig.  # noqa: E501


        :return: The qmax of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._qmax

    @qmax.setter
    def qmax(self, qmax):
        """Sets the qmax of this FactoryConfig.


        :param qmax: The qmax of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._qmax = qmax

    @property
    def qmin(self):
        """Gets the qmin of this FactoryConfig.  # noqa: E501


        :return: The qmin of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._qmin

    @qmin.setter
    def qmin(self, qmin):
        """Sets the qmin of this FactoryConfig.


        :param qmin: The qmin of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._qmin = qmin

    @property
    def rate_of_change_sum_range_set_value1(self):
        """Gets the rate_of_change_sum_range_set_value1 of this FactoryConfig.  # noqa: E501


        :return: The rate_of_change_sum_range_set_value1 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._rate_of_change_sum_range_set_value1

    @rate_of_change_sum_range_set_value1.setter
    def rate_of_change_sum_range_set_value1(self, rate_of_change_sum_range_set_value1):
        """Sets the rate_of_change_sum_range_set_value1 of this FactoryConfig.


        :param rate_of_change_sum_range_set_value1: The rate_of_change_sum_range_set_value1 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._rate_of_change_sum_range_set_value1 = rate_of_change_sum_range_set_value1

    @property
    def rate_of_change_sum_range_set_value2(self):
        """Gets the rate_of_change_sum_range_set_value2 of this FactoryConfig.  # noqa: E501


        :return: The rate_of_change_sum_range_set_value2 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._rate_of_change_sum_range_set_value2

    @rate_of_change_sum_range_set_value2.setter
    def rate_of_change_sum_range_set_value2(self, rate_of_change_sum_range_set_value2):
        """Sets the rate_of_change_sum_range_set_value2 of this FactoryConfig.


        :param rate_of_change_sum_range_set_value2: The rate_of_change_sum_range_set_value2 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._rate_of_change_sum_range_set_value2 = rate_of_change_sum_range_set_value2

    @property
    def rate_of_change_sum_range_set_value3(self):
        """Gets the rate_of_change_sum_range_set_value3 of this FactoryConfig.  # noqa: E501


        :return: The rate_of_change_sum_range_set_value3 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._rate_of_change_sum_range_set_value3

    @rate_of_change_sum_range_set_value3.setter
    def rate_of_change_sum_range_set_value3(self, rate_of_change_sum_range_set_value3):
        """Sets the rate_of_change_sum_range_set_value3 of this FactoryConfig.


        :param rate_of_change_sum_range_set_value3: The rate_of_change_sum_range_set_value3 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._rate_of_change_sum_range_set_value3 = rate_of_change_sum_range_set_value3

    @property
    def rate_of_change_sum_range_set_value4(self):
        """Gets the rate_of_change_sum_range_set_value4 of this FactoryConfig.  # noqa: E501


        :return: The rate_of_change_sum_range_set_value4 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._rate_of_change_sum_range_set_value4

    @rate_of_change_sum_range_set_value4.setter
    def rate_of_change_sum_range_set_value4(self, rate_of_change_sum_range_set_value4):
        """Sets the rate_of_change_sum_range_set_value4 of this FactoryConfig.


        :param rate_of_change_sum_range_set_value4: The rate_of_change_sum_range_set_value4 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._rate_of_change_sum_range_set_value4 = rate_of_change_sum_range_set_value4

    @property
    def pump_station_feedback_increase_value1(self):
        """Gets the pump_station_feedback_increase_value1 of this FactoryConfig.  # noqa: E501


        :return: The pump_station_feedback_increase_value1 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._pump_station_feedback_increase_value1

    @pump_station_feedback_increase_value1.setter
    def pump_station_feedback_increase_value1(self, pump_station_feedback_increase_value1):
        """Sets the pump_station_feedback_increase_value1 of this FactoryConfig.


        :param pump_station_feedback_increase_value1: The pump_station_feedback_increase_value1 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._pump_station_feedback_increase_value1 = pump_station_feedback_increase_value1

    @property
    def pump_station_feedback_increase_value2(self):
        """Gets the pump_station_feedback_increase_value2 of this FactoryConfig.  # noqa: E501


        :return: The pump_station_feedback_increase_value2 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._pump_station_feedback_increase_value2

    @pump_station_feedback_increase_value2.setter
    def pump_station_feedback_increase_value2(self, pump_station_feedback_increase_value2):
        """Sets the pump_station_feedback_increase_value2 of this FactoryConfig.


        :param pump_station_feedback_increase_value2: The pump_station_feedback_increase_value2 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._pump_station_feedback_increase_value2 = pump_station_feedback_increase_value2

    @property
    def pump_station_feedback_increase_value3(self):
        """Gets the pump_station_feedback_increase_value3 of this FactoryConfig.  # noqa: E501


        :return: The pump_station_feedback_increase_value3 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._pump_station_feedback_increase_value3

    @pump_station_feedback_increase_value3.setter
    def pump_station_feedback_increase_value3(self, pump_station_feedback_increase_value3):
        """Sets the pump_station_feedback_increase_value3 of this FactoryConfig.


        :param pump_station_feedback_increase_value3: The pump_station_feedback_increase_value3 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._pump_station_feedback_increase_value3 = pump_station_feedback_increase_value3

    @property
    def pump_station_feedback_increase_value4(self):
        """Gets the pump_station_feedback_increase_value4 of this FactoryConfig.  # noqa: E501


        :return: The pump_station_feedback_increase_value4 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._pump_station_feedback_increase_value4

    @pump_station_feedback_increase_value4.setter
    def pump_station_feedback_increase_value4(self, pump_station_feedback_increase_value4):
        """Sets the pump_station_feedback_increase_value4 of this FactoryConfig.


        :param pump_station_feedback_increase_value4: The pump_station_feedback_increase_value4 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._pump_station_feedback_increase_value4 = pump_station_feedback_increase_value4

    @property
    def pump_station_feedback_increase_value5(self):
        """Gets the pump_station_feedback_increase_value5 of this FactoryConfig.  # noqa: E501


        :return: The pump_station_feedback_increase_value5 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._pump_station_feedback_increase_value5

    @pump_station_feedback_increase_value5.setter
    def pump_station_feedback_increase_value5(self, pump_station_feedback_increase_value5):
        """Sets the pump_station_feedback_increase_value5 of this FactoryConfig.


        :param pump_station_feedback_increase_value5: The pump_station_feedback_increase_value5 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._pump_station_feedback_increase_value5 = pump_station_feedback_increase_value5

    @property
    def flow_change_value(self):
        """Gets the flow_change_value of this FactoryConfig.  # noqa: E501


        :return: The flow_change_value of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._flow_change_value

    @flow_change_value.setter
    def flow_change_value(self, flow_change_value):
        """Sets the flow_change_value of this FactoryConfig.


        :param flow_change_value: The flow_change_value of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._flow_change_value = flow_change_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FactoryConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FactoryConfig):
            return True

        return self.to_dict() != other.to_dict()
