# coding: utf-8

"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_information_service.configuration import Configuration


class RiverPump(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pump_id': 'str',
        'control_wl': 'float',
        'capacity': 'float'
    }

    attribute_map = {
        'pump_id': 'pumpID',
        'control_wl': 'controlWL',
        'capacity': 'capacity'
    }

    def __init__(self, pump_id=None, control_wl=None, capacity=None, local_vars_configuration=None):  # noqa: E501
        """RiverPump - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pump_id = None
        self._control_wl = None
        self._capacity = None
        self.discriminator = None

        self.pump_id = pump_id
        if control_wl is not None:
            self.control_wl = control_wl
        if capacity is not None:
            self.capacity = capacity

    @property
    def pump_id(self):
        """Gets the pump_id of this RiverPump.  # noqa: E501


        :return: The pump_id of this RiverPump.  # noqa: E501
        :rtype: str
        """
        return self._pump_id

    @pump_id.setter
    def pump_id(self, pump_id):
        """Sets the pump_id of this RiverPump.


        :param pump_id: The pump_id of this RiverPump.  # noqa: E501
        :type: str
        """

        self._pump_id = pump_id

    @property
    def control_wl(self):
        """Gets the control_wl of this RiverPump.  # noqa: E501


        :return: The control_wl of this RiverPump.  # noqa: E501
        :rtype: float
        """
        return self._control_wl

    @control_wl.setter
    def control_wl(self, control_wl):
        """Sets the control_wl of this RiverPump.


        :param control_wl: The control_wl of this RiverPump.  # noqa: E501
        :type: float
        """

        self._control_wl = control_wl

    @property
    def capacity(self):
        """Gets the capacity of this RiverPump.  # noqa: E501


        :return: The capacity of this RiverPump.  # noqa: E501
        :rtype: float
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this RiverPump.


        :param capacity: The capacity of this RiverPump.  # noqa: E501
        :type: float
        """

        self._capacity = capacity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RiverPump):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RiverPump):
            return True

        return self.to_dict() != other.to_dict()
