# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class WqOnlinePoint(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'product_line': 'str',
        'codes': 'list[str]',
        'units': 'list[str]',
        'point_codes': 'list[str]'
    }

    attribute_map = {
        'product_line': 'productLine',
        'codes': 'codes',
        'units': 'units',
        'point_codes': 'pointCodes'
    }

    def __init__(self, product_line=None, codes=None, units=None, point_codes=None, local_vars_configuration=None):  # noqa: E501
        """WqOnlinePoint - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._product_line = None
        self._codes = None
        self._units = None
        self._point_codes = None
        self.discriminator = None

        self.product_line = product_line
        self.codes = codes
        self.units = units
        self.point_codes = point_codes

    @property
    def product_line(self):
        """Gets the product_line of this WqOnlinePoint.  # noqa: E501

        进水点或工艺线 inlet name or product line name  # noqa: E501

        :return: The product_line of this WqOnlinePoint.  # noqa: E501
        :rtype: str
        """
        return self._product_line

    @product_line.setter
    def product_line(self, product_line):
        """Sets the product_line of this WqOnlinePoint.

        进水点或工艺线 inlet name or product line name  # noqa: E501

        :param product_line: The product_line of this WqOnlinePoint.  # noqa: E501
        :type: str
        """

        self._product_line = product_line

    @property
    def codes(self):
        """Gets the codes of this WqOnlinePoint.  # noqa: E501

        系统点位列表 system point codes/indicators  # noqa: E501

        :return: The codes of this WqOnlinePoint.  # noqa: E501
        :rtype: list[str]
        """
        return self._codes

    @codes.setter
    def codes(self, codes):
        """Sets the codes of this WqOnlinePoint.

        系统点位列表 system point codes/indicators  # noqa: E501

        :param codes: The codes of this WqOnlinePoint.  # noqa: E501
        :type: list[str]
        """

        self._codes = codes

    @property
    def units(self):
        """Gets the units of this WqOnlinePoint.  # noqa: E501

        单位列表 units  # noqa: E501

        :return: The units of this WqOnlinePoint.  # noqa: E501
        :rtype: list[str]
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this WqOnlinePoint.

        单位列表 units  # noqa: E501

        :param units: The units of this WqOnlinePoint.  # noqa: E501
        :type: list[str]
        """

        self._units = units

    @property
    def point_codes(self):
        """Gets the point_codes of this WqOnlinePoint.  # noqa: E501

        在线点位列表 corresponding online point codes  # noqa: E501

        :return: The point_codes of this WqOnlinePoint.  # noqa: E501
        :rtype: list[str]
        """
        return self._point_codes

    @point_codes.setter
    def point_codes(self, point_codes):
        """Sets the point_codes of this WqOnlinePoint.

        在线点位列表 corresponding online point codes  # noqa: E501

        :param point_codes: The point_codes of this WqOnlinePoint.  # noqa: E501
        :type: list[str]
        """

        self._point_codes = point_codes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WqOnlinePoint):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WqOnlinePoint):
            return True

        return self.to_dict() != other.to_dict()
