# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class SaveOutPointMapInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'device_name': 'str',
        'indicator': 'str',
        'model_point_type': 'str',
        'model_id': 'str',
        'model_data_type': 'str',
        'model_component': 'str',
        'template_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'device_name': 'deviceName',
        'indicator': 'indicator',
        'model_point_type': 'modelPointType',
        'model_id': 'modelId',
        'model_data_type': 'modelDataType',
        'model_component': 'modelComponent',
        'template_id': 'templateId'
    }

    def __init__(self, id=None, device_name=None, indicator=None, model_point_type=None, model_id=None, model_data_type=None, model_component=None, template_id=None, local_vars_configuration=None):  # noqa: E501
        """SaveOutPointMapInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._device_name = None
        self._indicator = None
        self._model_point_type = None
        self._model_id = None
        self._model_data_type = None
        self._model_component = None
        self._template_id = None
        self.discriminator = None

        self.id = id
        self.device_name = device_name
        self.indicator = indicator
        self.model_point_type = model_point_type
        self.model_id = model_id
        self.model_data_type = model_data_type
        self.model_component = model_component
        if template_id is not None:
            self.template_id = template_id

    @property
    def id(self):
        """Gets the id of this SaveOutPointMapInput.  # noqa: E501


        :return: The id of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SaveOutPointMapInput.


        :param id: The id of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def device_name(self):
        """Gets the device_name of this SaveOutPointMapInput.  # noqa: E501


        :return: The device_name of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._device_name

    @device_name.setter
    def device_name(self, device_name):
        """Sets the device_name of this SaveOutPointMapInput.


        :param device_name: The device_name of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._device_name = device_name

    @property
    def indicator(self):
        """Gets the indicator of this SaveOutPointMapInput.  # noqa: E501


        :return: The indicator of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this SaveOutPointMapInput.


        :param indicator: The indicator of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._indicator = indicator

    @property
    def model_point_type(self):
        """Gets the model_point_type of this SaveOutPointMapInput.  # noqa: E501


        :return: The model_point_type of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._model_point_type

    @model_point_type.setter
    def model_point_type(self, model_point_type):
        """Sets the model_point_type of this SaveOutPointMapInput.


        :param model_point_type: The model_point_type of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._model_point_type = model_point_type

    @property
    def model_id(self):
        """Gets the model_id of this SaveOutPointMapInput.  # noqa: E501


        :return: The model_id of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this SaveOutPointMapInput.


        :param model_id: The model_id of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._model_id = model_id

    @property
    def model_data_type(self):
        """Gets the model_data_type of this SaveOutPointMapInput.  # noqa: E501


        :return: The model_data_type of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._model_data_type

    @model_data_type.setter
    def model_data_type(self, model_data_type):
        """Sets the model_data_type of this SaveOutPointMapInput.


        :param model_data_type: The model_data_type of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._model_data_type = model_data_type

    @property
    def model_component(self):
        """Gets the model_component of this SaveOutPointMapInput.  # noqa: E501


        :return: The model_component of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._model_component

    @model_component.setter
    def model_component(self, model_component):
        """Sets the model_component of this SaveOutPointMapInput.


        :param model_component: The model_component of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._model_component = model_component

    @property
    def template_id(self):
        """Gets the template_id of this SaveOutPointMapInput.  # noqa: E501


        :return: The template_id of this SaveOutPointMapInput.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this SaveOutPointMapInput.


        :param template_id: The template_id of this SaveOutPointMapInput.  # noqa: E501
        :type: str
        """

        self._template_id = template_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SaveOutPointMapInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SaveOutPointMapInput):
            return True

        return self.to_dict() != other.to_dict()
