# coding: utf-8

"""
    wwtp-paas-infrastructure-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_infrastructure_service.configuration import Configuration


class ModelInputFileConfigOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'model_name': 'str',
        'input_file_name': 'str',
        'input_file_type': 'int',
        'model_node': 'str',
        'online_point': 'str',
        'unit': 'str',
        'unit_convert_ratio': 'float'
    }

    attribute_map = {
        'id': 'id',
        'model_name': 'modelName',
        'input_file_name': 'inputFileName',
        'input_file_type': 'inputFileType',
        'model_node': 'modelNode',
        'online_point': 'onlinePoint',
        'unit': 'unit',
        'unit_convert_ratio': 'unitConvertRatio'
    }

    def __init__(self, id=None, model_name=None, input_file_name=None, input_file_type=None, model_node=None, online_point=None, unit=None, unit_convert_ratio=None, local_vars_configuration=None):  # noqa: E501
        """ModelInputFileConfigOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._model_name = None
        self._input_file_name = None
        self._input_file_type = None
        self._model_node = None
        self._online_point = None
        self._unit = None
        self._unit_convert_ratio = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.model_name = model_name
        self.input_file_name = input_file_name
        if input_file_type is not None:
            self.input_file_type = input_file_type
        self.model_node = model_node
        self.online_point = online_point
        self.unit = unit
        if unit_convert_ratio is not None:
            self.unit_convert_ratio = unit_convert_ratio

    @property
    def id(self):
        """Gets the id of this ModelInputFileConfigOutput.  # noqa: E501

        模型输入文件配置ID config id  # noqa: E501

        :return: The id of this ModelInputFileConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ModelInputFileConfigOutput.

        模型输入文件配置ID config id  # noqa: E501

        :param id: The id of this ModelInputFileConfigOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def model_name(self):
        """Gets the model_name of this ModelInputFileConfigOutput.  # noqa: E501

        模板模型名称（即模板方案名称） template scenario name  # noqa: E501

        :return: The model_name of this ModelInputFileConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this ModelInputFileConfigOutput.

        模板模型名称（即模板方案名称） template scenario name  # noqa: E501

        :param model_name: The model_name of this ModelInputFileConfigOutput.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    @property
    def input_file_name(self):
        """Gets the input_file_name of this ModelInputFileConfigOutput.  # noqa: E501

        输入文件名 input file name  # noqa: E501

        :return: The input_file_name of this ModelInputFileConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._input_file_name

    @input_file_name.setter
    def input_file_name(self, input_file_name):
        """Sets the input_file_name of this ModelInputFileConfigOutput.

        输入文件名 input file name  # noqa: E501

        :param input_file_name: The input_file_name of this ModelInputFileConfigOutput.  # noqa: E501
        :type: str
        """

        self._input_file_name = input_file_name

    @property
    def input_file_type(self):
        """Gets the input_file_type of this ModelInputFileConfigOutput.  # noqa: E501

        输入文件类型 input file type  # noqa: E501

        :return: The input_file_type of this ModelInputFileConfigOutput.  # noqa: E501
        :rtype: int
        """
        return self._input_file_type

    @input_file_type.setter
    def input_file_type(self, input_file_type):
        """Sets the input_file_type of this ModelInputFileConfigOutput.

        输入文件类型 input file type  # noqa: E501

        :param input_file_type: The input_file_type of this ModelInputFileConfigOutput.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and input_file_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `input_file_type` ({0}), must be one of {1}"  # noqa: E501
                .format(input_file_type, allowed_values)
            )

        self._input_file_type = input_file_type

    @property
    def model_node(self):
        """Gets the model_node of this ModelInputFileConfigOutput.  # noqa: E501

        对应模型点位编号 model node code  # noqa: E501

        :return: The model_node of this ModelInputFileConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._model_node

    @model_node.setter
    def model_node(self, model_node):
        """Sets the model_node of this ModelInputFileConfigOutput.

        对应模型点位编号 model node code  # noqa: E501

        :param model_node: The model_node of this ModelInputFileConfigOutput.  # noqa: E501
        :type: str
        """

        self._model_node = model_node

    @property
    def online_point(self):
        """Gets the online_point of this ModelInputFileConfigOutput.  # noqa: E501

        对应在线点位编号 online point code  # noqa: E501

        :return: The online_point of this ModelInputFileConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._online_point

    @online_point.setter
    def online_point(self, online_point):
        """Sets the online_point of this ModelInputFileConfigOutput.

        对应在线点位编号 online point code  # noqa: E501

        :param online_point: The online_point of this ModelInputFileConfigOutput.  # noqa: E501
        :type: str
        """

        self._online_point = online_point

    @property
    def unit(self):
        """Gets the unit of this ModelInputFileConfigOutput.  # noqa: E501

        单位(模型中的单位) unit  # noqa: E501

        :return: The unit of this ModelInputFileConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this ModelInputFileConfigOutput.

        单位(模型中的单位) unit  # noqa: E501

        :param unit: The unit of this ModelInputFileConfigOutput.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def unit_convert_ratio(self):
        """Gets the unit_convert_ratio of this ModelInputFileConfigOutput.  # noqa: E501

        单位转换比率(在线点位与模型点位的单位转换比) unit convert ratio  # noqa: E501

        :return: The unit_convert_ratio of this ModelInputFileConfigOutput.  # noqa: E501
        :rtype: float
        """
        return self._unit_convert_ratio

    @unit_convert_ratio.setter
    def unit_convert_ratio(self, unit_convert_ratio):
        """Sets the unit_convert_ratio of this ModelInputFileConfigOutput.

        单位转换比率(在线点位与模型点位的单位转换比) unit convert ratio  # noqa: E501

        :param unit_convert_ratio: The unit_convert_ratio of this ModelInputFileConfigOutput.  # noqa: E501
        :type: float
        """

        self._unit_convert_ratio = unit_convert_ratio

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelInputFileConfigOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelInputFileConfigOutput):
            return True

        return self.to_dict() != other.to_dict()
