# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class IndicatorInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'device_info': 'DeviceInfo',
        'id': 'str',
        'device_id': 'str',
        'indicator': 'str',
        'show_name': 'str',
        'label': 'str',
        'type': 'str',
        'unit': 'str',
        'min_value': 'float',
        'max_value': 'float',
        'wd_indicator_attr': 'WdIndicatorAttr'
    }

    attribute_map = {
        'device_info': 'deviceInfo',
        'id': 'id',
        'device_id': 'deviceId',
        'indicator': 'indicator',
        'show_name': 'showName',
        'label': 'label',
        'type': 'type',
        'unit': 'unit',
        'min_value': 'minValue',
        'max_value': 'maxValue',
        'wd_indicator_attr': 'wdIndicatorAttr'
    }

    def __init__(self, device_info=None, id=None, device_id=None, indicator=None, show_name=None, label=None, type=None, unit=None, min_value=None, max_value=None, wd_indicator_attr=None, local_vars_configuration=None):  # noqa: E501
        """IndicatorInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._device_info = None
        self._id = None
        self._device_id = None
        self._indicator = None
        self._show_name = None
        self._label = None
        self._type = None
        self._unit = None
        self._min_value = None
        self._max_value = None
        self._wd_indicator_attr = None
        self.discriminator = None

        if device_info is not None:
            self.device_info = device_info
        if id is not None:
            self.id = id
        if device_id is not None:
            self.device_id = device_id
        self.indicator = indicator
        self.show_name = show_name
        self.label = label
        self.type = type
        self.unit = unit
        if min_value is not None:
            self.min_value = min_value
        if max_value is not None:
            self.max_value = max_value
        if wd_indicator_attr is not None:
            self.wd_indicator_attr = wd_indicator_attr

    @property
    def device_info(self):
        """Gets the device_info of this IndicatorInfo.  # noqa: E501


        :return: The device_info of this IndicatorInfo.  # noqa: E501
        :rtype: DeviceInfo
        """
        return self._device_info

    @device_info.setter
    def device_info(self, device_info):
        """Sets the device_info of this IndicatorInfo.


        :param device_info: The device_info of this IndicatorInfo.  # noqa: E501
        :type: DeviceInfo
        """

        self._device_info = device_info

    @property
    def id(self):
        """Gets the id of this IndicatorInfo.  # noqa: E501

        指标id  # noqa: E501

        :return: The id of this IndicatorInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IndicatorInfo.

        指标id  # noqa: E501

        :param id: The id of this IndicatorInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def device_id(self):
        """Gets the device_id of this IndicatorInfo.  # noqa: E501

        设备Id  # noqa: E501

        :return: The device_id of this IndicatorInfo.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this IndicatorInfo.

        设备Id  # noqa: E501

        :param device_id: The device_id of this IndicatorInfo.  # noqa: E501
        :type: str
        """

        self._device_id = device_id

    @property
    def indicator(self):
        """Gets the indicator of this IndicatorInfo.  # noqa: E501

        指标  # noqa: E501

        :return: The indicator of this IndicatorInfo.  # noqa: E501
        :rtype: str
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this IndicatorInfo.

        指标  # noqa: E501

        :param indicator: The indicator of this IndicatorInfo.  # noqa: E501
        :type: str
        """

        self._indicator = indicator

    @property
    def show_name(self):
        """Gets the show_name of this IndicatorInfo.  # noqa: E501

        指标显示名称  # noqa: E501

        :return: The show_name of this IndicatorInfo.  # noqa: E501
        :rtype: str
        """
        return self._show_name

    @show_name.setter
    def show_name(self, show_name):
        """Sets the show_name of this IndicatorInfo.

        指标显示名称  # noqa: E501

        :param show_name: The show_name of this IndicatorInfo.  # noqa: E501
        :type: str
        """

        self._show_name = show_name

    @property
    def label(self):
        """Gets the label of this IndicatorInfo.  # noqa: E501

        标签  # noqa: E501

        :return: The label of this IndicatorInfo.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this IndicatorInfo.

        标签  # noqa: E501

        :param label: The label of this IndicatorInfo.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def type(self):
        """Gets the type of this IndicatorInfo.  # noqa: E501

        指标类型  # noqa: E501

        :return: The type of this IndicatorInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this IndicatorInfo.

        指标类型  # noqa: E501

        :param type: The type of this IndicatorInfo.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def unit(self):
        """Gets the unit of this IndicatorInfo.  # noqa: E501

        指标单位  # noqa: E501

        :return: The unit of this IndicatorInfo.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this IndicatorInfo.

        指标单位  # noqa: E501

        :param unit: The unit of this IndicatorInfo.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def min_value(self):
        """Gets the min_value of this IndicatorInfo.  # noqa: E501


        :return: The min_value of this IndicatorInfo.  # noqa: E501
        :rtype: float
        """
        return self._min_value

    @min_value.setter
    def min_value(self, min_value):
        """Sets the min_value of this IndicatorInfo.


        :param min_value: The min_value of this IndicatorInfo.  # noqa: E501
        :type: float
        """

        self._min_value = min_value

    @property
    def max_value(self):
        """Gets the max_value of this IndicatorInfo.  # noqa: E501


        :return: The max_value of this IndicatorInfo.  # noqa: E501
        :rtype: float
        """
        return self._max_value

    @max_value.setter
    def max_value(self, max_value):
        """Sets the max_value of this IndicatorInfo.


        :param max_value: The max_value of this IndicatorInfo.  # noqa: E501
        :type: float
        """

        self._max_value = max_value

    @property
    def wd_indicator_attr(self):
        """Gets the wd_indicator_attr of this IndicatorInfo.  # noqa: E501


        :return: The wd_indicator_attr of this IndicatorInfo.  # noqa: E501
        :rtype: WdIndicatorAttr
        """
        return self._wd_indicator_attr

    @wd_indicator_attr.setter
    def wd_indicator_attr(self, wd_indicator_attr):
        """Sets the wd_indicator_attr of this IndicatorInfo.


        :param wd_indicator_attr: The wd_indicator_attr of this IndicatorInfo.  # noqa: E501
        :type: WdIndicatorAttr
        """

        self._wd_indicator_attr = wd_indicator_attr

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IndicatorInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IndicatorInfo):
            return True

        return self.to_dict() != other.to_dict()
