# coding: utf-8

# flake8: noqa
"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from dhicn_wwtp_data_bus_service.models.abft_process_status_output import AbftProcessStatusOutput
from dhicn_wwtp_data_bus_service.models.add_model_precision_config_input import AddModelPrecisionConfigInput
from dhicn_wwtp_data_bus_service.models.add_pro_num_sim_lab_index_config_input import AddProNumSimLabIndexConfigInput
from dhicn_wwtp_data_bus_service.models.add_sys_statistic_configs_input import AddSysStatisticConfigsInput
from dhicn_wwtp_data_bus_service.models.alarm_config_in_out import AlarmConfigInOut
from dhicn_wwtp_data_bus_service.models.assembly_config_output import AssemblyConfigOutput
from dhicn_wwtp_data_bus_service.models.bio_value import BioValue
from dhicn_wwtp_data_bus_service.models.build_calc_dosage_config_in_out import BuildCalcDosageConfigInOut
from dhicn_wwtp_data_bus_service.models.catalysis_bf_output import CatalysisBfOutput
from dhicn_wwtp_data_bus_service.models.catalysis_tank_output import CatalysisTankOutput
from dhicn_wwtp_data_bus_service.models.cd_addition_rate_output import CdAdditionRateOutput
from dhicn_wwtp_data_bus_service.models.chemical_cost_per_flow_output import ChemicalCostPerFlowOutput
from dhicn_wwtp_data_bus_service.models.code_unit import CodeUnit
from dhicn_wwtp_data_bus_service.models.config_item import ConfigItem
from dhicn_wwtp_data_bus_service.models.control_item import ControlItem
from dhicn_wwtp_data_bus_service.models.control_online_point_output import ControlOnlinePointOutput
from dhicn_wwtp_data_bus_service.models.cost_data import CostData
from dhicn_wwtp_data_bus_service.models.daily_accumulation_value import DailyAccumulationValue
from dhicn_wwtp_data_bus_service.models.data import Data
from dhicn_wwtp_data_bus_service.models.data_board_full_out import DataBoardFullOut
from dhicn_wwtp_data_bus_service.models.delete_scenario_input import DeleteScenarioInput
from dhicn_wwtp_data_bus_service.models.device_maintenance_output import DeviceMaintenanceOutput
from dhicn_wwtp_data_bus_service.models.dosing_log_output import DosingLogOutput
from dhicn_wwtp_data_bus_service.models.dosing_param_setting_dto import DosingParamSettingDto
from dhicn_wwtp_data_bus_service.models.dosing_parameter_output import DosingParameterOutput
from dhicn_wwtp_data_bus_service.models.dosing_statistic_dailys_in_out import DosingStatisticDailysInOut
from dhicn_wwtp_data_bus_service.models.dosing_statistic_dailys_output import DosingStatisticDailysOutput
from dhicn_wwtp_data_bus_service.models.dosing_statistic_monthlys_in_out import DosingStatisticMonthlysInOut
from dhicn_wwtp_data_bus_service.models.entire_process_ts import EntireProcessTs
from dhicn_wwtp_data_bus_service.models.entire_process_wq_out import EntireProcessWqOut
from dhicn_wwtp_data_bus_service.models.execute_plc_input import ExecutePlcInput
from dhicn_wwtp_data_bus_service.models.expression_info import ExpressionInfo
from dhicn_wwtp_data_bus_service.models.get_pro_num_sim_lab_index_config_output import GetProNumSimLabIndexConfigOutput
from dhicn_wwtp_data_bus_service.models.get_statistic_result_dto import GetStatisticResultDto
from dhicn_wwtp_data_bus_service.models.global_config_in_out import GlobalConfigInOut
from dhicn_wwtp_data_bus_service.models.group_data import GroupData
from dhicn_wwtp_data_bus_service.models.hp_display_config_in_out import HpDisplayConfigInOut
from dhicn_wwtp_data_bus_service.models.inlet_load_output import InletLoadOutput
from dhicn_wwtp_data_bus_service.models.inlet_parameters_output import InletParametersOutput
from dhicn_wwtp_data_bus_service.models.inlet_wq_out import InletWqOut
from dhicn_wwtp_data_bus_service.models.inline_object import InlineObject
from dhicn_wwtp_data_bus_service.models.inline_object1 import InlineObject1
from dhicn_wwtp_data_bus_service.models.intelligent_deni_config_in_out import IntelligentDeniConfigInOut
from dhicn_wwtp_data_bus_service.models.mapping_config_input_output import MappingConfigInputOutput
from dhicn_wwtp_data_bus_service.models.micro_organism_output import MicroOrganismOutput
from dhicn_wwtp_data_bus_service.models.model_node_config_input_output import ModelNodeConfigInputOutput
from dhicn_wwtp_data_bus_service.models.model_optim_dto import ModelOptimDto
from dhicn_wwtp_data_bus_service.models.model_param import ModelParam
from dhicn_wwtp_data_bus_service.models.model_precision import ModelPrecision
from dhicn_wwtp_data_bus_service.models.model_precision_configs_dto import ModelPrecisionConfigsDto
from dhicn_wwtp_data_bus_service.models.online_point_config_input_output import OnlinePointConfigInputOutput
from dhicn_wwtp_data_bus_service.models.outlet_tn_output import OutletTnOutput
from dhicn_wwtp_data_bus_service.models.outlet_wq_out import OutletWqOut
from dhicn_wwtp_data_bus_service.models.percentages_dto import PercentagesDto
from dhicn_wwtp_data_bus_service.models.point_value import PointValue
from dhicn_wwtp_data_bus_service.models.precision_wq import PrecisionWq
from dhicn_wwtp_data_bus_service.models.predict_alarm_out import PredictAlarmOut
from dhicn_wwtp_data_bus_service.models.processed_setting_dto import ProcessedSettingDto
from dhicn_wwtp_data_bus_service.models.query_biochemicaltanks_output import QueryBiochemicaltanksOutput
from dhicn_wwtp_data_bus_service.models.query_by_condition_input import QueryByConditionInput
from dhicn_wwtp_data_bus_service.models.query_control_param_compare_input import QueryControlParamCompareInput
from dhicn_wwtp_data_bus_service.models.query_control_param_compare_output import QueryControlParamCompareOutput
from dhicn_wwtp_data_bus_service.models.query_indicator_statistic_output import QueryIndicatorStatisticOutput
from dhicn_wwtp_data_bus_service.models.query_inlet_data_output import QueryInletDataOutput
from dhicn_wwtp_data_bus_service.models.real_time_data import RealTimeData
from dhicn_wwtp_data_bus_service.models.real_time_output import RealTimeOutput
from dhicn_wwtp_data_bus_service.models.remote_service_error_info import RemoteServiceErrorInfo
from dhicn_wwtp_data_bus_service.models.remote_service_error_response import RemoteServiceErrorResponse
from dhicn_wwtp_data_bus_service.models.remote_service_validation_error_info import RemoteServiceValidationErrorInfo
from dhicn_wwtp_data_bus_service.models.result_param import ResultParam
from dhicn_wwtp_data_bus_service.models.result_setting import ResultSetting
from dhicn_wwtp_data_bus_service.models.save_inlet_data_input import SaveInletDataInput
from dhicn_wwtp_data_bus_service.models.save_param_input import SaveParamInput
from dhicn_wwtp_data_bus_service.models.scenario import Scenario
from dhicn_wwtp_data_bus_service.models.scenario_model_node_dto import ScenarioModelNodeDto
from dhicn_wwtp_data_bus_service.models.select_item_node import SelectItemNode
from dhicn_wwtp_data_bus_service.models.select_item_node_detail_info import SelectItemNodeDetailInfo
from dhicn_wwtp_data_bus_service.models.sim_results_outupt import SimResultsOutupt
from dhicn_wwtp_data_bus_service.models.single_code_datas_output import SingleCodeDatasOutput
from dhicn_wwtp_data_bus_service.models.statis_data_boards_view import StatisDataBoardsView
from dhicn_wwtp_data_bus_service.models.statistic_data import StatisticData
from dhicn_wwtp_data_bus_service.models.statistic_var_ref_dto import StatisticVarRefDto
from dhicn_wwtp_data_bus_service.models.string_list_result import StringListResult
from dhicn_wwtp_data_bus_service.models.svr_point_info import SvrPointInfo
from dhicn_wwtp_data_bus_service.models.sys_code_config_input_output import SysCodeConfigInputOutput
from dhicn_wwtp_data_bus_service.models.sys_statistic_config import SysStatisticConfig
from dhicn_wwtp_data_bus_service.models.sys_statistic_config_in_out import SysStatisticConfigInOut
from dhicn_wwtp_data_bus_service.models.toxic_alarms_output import ToxicAlarmsOutput
from dhicn_wwtp_data_bus_service.models.toxicity_input import ToxicityInput
from dhicn_wwtp_data_bus_service.models.toxicity_output import ToxicityOutput
from dhicn_wwtp_data_bus_service.models.ts_data import TsData
from dhicn_wwtp_data_bus_service.models.ts_data_output import TsDataOutput
from dhicn_wwtp_data_bus_service.models.ts_pair import TsPair
from dhicn_wwtp_data_bus_service.models.ts_pair1 import TsPair1
from dhicn_wwtp_data_bus_service.models.update_sys_statistic_configs_input import UpdateSysStatisticConfigsInput
from dhicn_wwtp_data_bus_service.models.update_wq_input_data_input import UpdateWqInputDataInput
from dhicn_wwtp_data_bus_service.models.wq_online_data_input import WqOnlineDataInput
from dhicn_wwtp_data_bus_service.models.wq_online_data_output import WqOnlineDataOutput
from dhicn_wwtp_data_bus_service.models.wq_online_point import WqOnlinePoint
from dhicn_wwtp_data_bus_service.models.wq_online_point_output import WqOnlinePointOutput
from dhicn_wwtp_data_bus_service.models.wq_simulation_indicator_input import WqSimulationIndicatorInput
from dhicn_wwtp_data_bus_service.models.wq_simulation_indicator_output import WqSimulationIndicatorOutput
from dhicn_wwtp_data_bus_service.models.wq_statistic_output import WqStatisticOutput
